"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BackupMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class FrankingMetadata(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            FRANKINGTAG_FIELD_NUMBER: builtins.int
            REPORTINGTAG_FIELD_NUMBER: builtins.int
            frankingTag: builtins.bytes
            reportingTag: builtins.bytes
            def __init__(
                self,
                *,
                frankingTag: builtins.bytes | None = ...,
                reportingTag: builtins.bytes | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["frankingTag", b"frankingTag", "reportingTag", b"reportingTag"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["frankingTag", b"frankingTag", "reportingTag", b"reportingTag"]) -> None: ...

        SENDERID_FIELD_NUMBER: builtins.int
        MESSAGEID_FIELD_NUMBER: builtins.int
        TIMESTAMPMS_FIELD_NUMBER: builtins.int
        FRANKINGMETADATA_FIELD_NUMBER: builtins.int
        PAYLOADVERSION_FIELD_NUMBER: builtins.int
        FUTUREPROOFBEHAVIOR_FIELD_NUMBER: builtins.int
        THREADTYPETAG_FIELD_NUMBER: builtins.int
        senderID: builtins.str
        messageID: builtins.str
        timestampMS: builtins.int
        payloadVersion: builtins.int
        futureProofBehavior: builtins.int
        threadTypeTag: builtins.int
        @property
        def frankingMetadata(self) -> global___BackupMessage.Metadata.FrankingMetadata: ...
        def __init__(
            self,
            *,
            senderID: builtins.str | None = ...,
            messageID: builtins.str | None = ...,
            timestampMS: builtins.int | None = ...,
            frankingMetadata: global___BackupMessage.Metadata.FrankingMetadata | None = ...,
            payloadVersion: builtins.int | None = ...,
            futureProofBehavior: builtins.int | None = ...,
            threadTypeTag: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["frankingMetadata", b"frankingMetadata", "futureProofBehavior", b"futureProofBehavior", "messageID", b"messageID", "payloadVersion", b"payloadVersion", "senderID", b"senderID", "threadTypeTag", b"threadTypeTag", "timestampMS", b"timestampMS"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["frankingMetadata", b"frankingMetadata", "futureProofBehavior", b"futureProofBehavior", "messageID", b"messageID", "payloadVersion", b"payloadVersion", "senderID", b"senderID", "threadTypeTag", b"threadTypeTag", "timestampMS", b"timestampMS"]) -> None: ...

    ENCRYPTEDTRANSPORTMESSAGE_FIELD_NUMBER: builtins.int
    ENCRYPTEDTRANSPORTEVENT_FIELD_NUMBER: builtins.int
    ENCRYPTEDTRANSPORTLOCALLYTRANSFORMEDMESSAGE_FIELD_NUMBER: builtins.int
    MITRANSPORTADMINMESSAGE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    encryptedTransportMessage: builtins.bytes
    @property
    def encryptedTransportEvent(self) -> waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol: ...
    @property
    def encryptedTransportLocallyTransformedMessage(self) -> waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol: ...
    @property
    def miTransportAdminMessage(self) -> waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol: ...
    @property
    def metadata(self) -> global___BackupMessage.Metadata: ...
    def __init__(
        self,
        *,
        encryptedTransportMessage: builtins.bytes | None = ...,
        encryptedTransportEvent: waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol | None = ...,
        encryptedTransportLocallyTransformedMessage: waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol | None = ...,
        miTransportAdminMessage: waArmadilloBackupCommon.WAArmadilloBackupCommon_pb2.Subprotocol | None = ...,
        metadata: global___BackupMessage.Metadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["encryptedTransportEvent", b"encryptedTransportEvent", "encryptedTransportLocallyTransformedMessage", b"encryptedTransportLocallyTransformedMessage", "encryptedTransportMessage", b"encryptedTransportMessage", "metadata", b"metadata", "miTransportAdminMessage", b"miTransportAdminMessage", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["encryptedTransportEvent", b"encryptedTransportEvent", "encryptedTransportLocallyTransformedMessage", b"encryptedTransportLocallyTransformedMessage", "encryptedTransportMessage", b"encryptedTransportMessage", "metadata", b"metadata", "miTransportAdminMessage", b"miTransportAdminMessage", "payload", b"payload"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["payload", b"payload"]) -> typing.Literal["encryptedTransportMessage", "encryptedTransportEvent", "encryptedTransportLocallyTransformedMessage", "miTransportAdminMessage"] | None: ...

global___BackupMessage = BackupMessage



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ExtendedContentMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _OverlayIconGlyph:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _OverlayIconGlyphEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExtendedContentMessage._OverlayIconGlyph.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INFO: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 0
        EYE_OFF: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 1
        NEWS_OFF: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 2
        WARNING: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 3
        PRIVATE: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 4
        NONE: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 5
        MEDIA_LABEL: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 6
        POST_COVER: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 7
        POST_LABEL: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 8
        WARNING_SCREENS: ExtendedContentMessage._OverlayIconGlyph.ValueType  # 9

    class OverlayIconGlyph(_OverlayIconGlyph, metaclass=_OverlayIconGlyphEnumTypeWrapper): ...
    INFO: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 0
    EYE_OFF: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 1
    NEWS_OFF: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 2
    WARNING: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 3
    PRIVATE: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 4
    NONE: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 5
    MEDIA_LABEL: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 6
    POST_COVER: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 7
    POST_LABEL: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 8
    WARNING_SCREENS: ExtendedContentMessage.OverlayIconGlyph.ValueType  # 9

    class _CtaButtonType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CtaButtonTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExtendedContentMessage._CtaButtonType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OPEN_NATIVE: ExtendedContentMessage._CtaButtonType.ValueType  # 11

    class CtaButtonType(_CtaButtonType, metaclass=_CtaButtonTypeEnumTypeWrapper): ...
    OPEN_NATIVE: ExtendedContentMessage.CtaButtonType.ValueType  # 11

    class _XmaLayoutType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmaLayoutTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExtendedContentMessage._XmaLayoutType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SINGLE: ExtendedContentMessage._XmaLayoutType.ValueType  # 0
        HSCROLL: ExtendedContentMessage._XmaLayoutType.ValueType  # 1
        PORTRAIT: ExtendedContentMessage._XmaLayoutType.ValueType  # 3
        STANDARD_DXMA: ExtendedContentMessage._XmaLayoutType.ValueType  # 12
        LIST_DXMA: ExtendedContentMessage._XmaLayoutType.ValueType  # 15
        GRID: ExtendedContentMessage._XmaLayoutType.ValueType  # 16

    class XmaLayoutType(_XmaLayoutType, metaclass=_XmaLayoutTypeEnumTypeWrapper): ...
    SINGLE: ExtendedContentMessage.XmaLayoutType.ValueType  # 0
    HSCROLL: ExtendedContentMessage.XmaLayoutType.ValueType  # 1
    PORTRAIT: ExtendedContentMessage.XmaLayoutType.ValueType  # 3
    STANDARD_DXMA: ExtendedContentMessage.XmaLayoutType.ValueType  # 12
    LIST_DXMA: ExtendedContentMessage.XmaLayoutType.ValueType  # 15
    GRID: ExtendedContentMessage.XmaLayoutType.ValueType  # 16

    class _ExtendedContentType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ExtendedContentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExtendedContentMessage._ExtendedContentType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNSUPPORTED: ExtendedContentMessage._ExtendedContentType.ValueType  # 0
        IG_STORY_PHOTO_MENTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 4
        IG_SINGLE_IMAGE_POST_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 9
        IG_MULTIPOST_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 10
        IG_SINGLE_VIDEO_POST_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 11
        IG_STORY_PHOTO_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 12
        IG_STORY_VIDEO_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 13
        IG_CLIPS_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 14
        IG_IGTV_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 15
        IG_SHOP_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 16
        IG_PROFILE_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 19
        IG_STORY_PHOTO_HIGHLIGHT_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 20
        IG_STORY_VIDEO_HIGHLIGHT_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 21
        IG_STORY_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 22
        IG_STORY_REACTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 23
        IG_STORY_VIDEO_MENTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 24
        IG_STORY_HIGHLIGHT_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 25
        IG_STORY_HIGHLIGHT_REACTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 26
        IG_EXTERNAL_LINK: ExtendedContentMessage._ExtendedContentType.ValueType  # 27
        IG_RECEIVER_FETCH: ExtendedContentMessage._ExtendedContentType.ValueType  # 28
        FB_FEED_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 1000
        FB_STORY_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 1001
        FB_STORY_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 1002
        FB_STORY_MENTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 1003
        FB_FEED_VIDEO_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 1004
        FB_GAMING_CUSTOM_UPDATE: ExtendedContentMessage._ExtendedContentType.ValueType  # 1005
        FB_PRODUCER_STORY_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 1006
        FB_EVENT: ExtendedContentMessage._ExtendedContentType.ValueType  # 1007
        FB_FEED_POST_PRIVATE_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 1008
        FB_SHORT: ExtendedContentMessage._ExtendedContentType.ValueType  # 1009
        FB_COMMENT_MENTION_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 1010
        FB_POST_MENTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 1011
        MSG_EXTERNAL_LINK_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 2000
        MSG_P2P_PAYMENT: ExtendedContentMessage._ExtendedContentType.ValueType  # 2001
        MSG_LOCATION_SHARING: ExtendedContentMessage._ExtendedContentType.ValueType  # 2002
        MSG_LOCATION_SHARING_V2: ExtendedContentMessage._ExtendedContentType.ValueType  # 2003
        MSG_HIGHLIGHTS_TAB_FRIEND_UPDATES_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 2004
        MSG_HIGHLIGHTS_TAB_LOCAL_EVENT_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 2005
        MSG_RECEIVER_FETCH: ExtendedContentMessage._ExtendedContentType.ValueType  # 2006
        MSG_IG_MEDIA_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 2007
        MSG_GEN_AI_SEARCH_PLUGIN_RESPONSE: ExtendedContentMessage._ExtendedContentType.ValueType  # 2008
        MSG_REELS_LIST: ExtendedContentMessage._ExtendedContentType.ValueType  # 2009
        MSG_CONTACT: ExtendedContentMessage._ExtendedContentType.ValueType  # 2010
        MSG_THREADS_POST_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 2011
        MSG_FILE: ExtendedContentMessage._ExtendedContentType.ValueType  # 2012
        MSG_AVATAR_DETAILS: ExtendedContentMessage._ExtendedContentType.ValueType  # 2013
        MSG_AI_CONTACT: ExtendedContentMessage._ExtendedContentType.ValueType  # 2014
        MSG_MEMORIES_SHARE: ExtendedContentMessage._ExtendedContentType.ValueType  # 2015
        MSG_SHARED_ALBUM_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 2016
        MSG_SHARED_ALBUM: ExtendedContentMessage._ExtendedContentType.ValueType  # 2017
        MSG_OCCAMADILLO_XMA: ExtendedContentMessage._ExtendedContentType.ValueType  # 2018
        MSG_GEN_AI_SUBSCRIPTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 2021
        MSG_GEN_AI_REMINDER: ExtendedContentMessage._ExtendedContentType.ValueType  # 2022
        MSG_GEN_AI_MEMU_ONBOARDING_RESPONSE: ExtendedContentMessage._ExtendedContentType.ValueType  # 2023
        MSG_NOTE_REPLY: ExtendedContentMessage._ExtendedContentType.ValueType  # 2024
        MSG_NOTE_MENTION: ExtendedContentMessage._ExtendedContentType.ValueType  # 2025
        RTC_AUDIO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3000
        RTC_VIDEO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3001
        RTC_MISSED_AUDIO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3002
        RTC_MISSED_VIDEO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3003
        RTC_GROUP_AUDIO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3004
        RTC_GROUP_VIDEO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3005
        RTC_MISSED_GROUP_AUDIO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3006
        RTC_MISSED_GROUP_VIDEO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3007
        RTC_ONGOING_AUDIO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3008
        RTC_ONGOING_VIDEO_CALL: ExtendedContentMessage._ExtendedContentType.ValueType  # 3009
        MSG_RECEIVER_FETCH_FALLBACK: ExtendedContentMessage._ExtendedContentType.ValueType  # 3025
        DATACLASS_SENDER_COPY: ExtendedContentMessage._ExtendedContentType.ValueType  # 4000

    class ExtendedContentType(_ExtendedContentType, metaclass=_ExtendedContentTypeEnumTypeWrapper): ...
    UNSUPPORTED: ExtendedContentMessage.ExtendedContentType.ValueType  # 0
    IG_STORY_PHOTO_MENTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 4
    IG_SINGLE_IMAGE_POST_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 9
    IG_MULTIPOST_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 10
    IG_SINGLE_VIDEO_POST_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 11
    IG_STORY_PHOTO_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 12
    IG_STORY_VIDEO_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 13
    IG_CLIPS_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 14
    IG_IGTV_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 15
    IG_SHOP_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 16
    IG_PROFILE_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 19
    IG_STORY_PHOTO_HIGHLIGHT_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 20
    IG_STORY_VIDEO_HIGHLIGHT_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 21
    IG_STORY_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 22
    IG_STORY_REACTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 23
    IG_STORY_VIDEO_MENTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 24
    IG_STORY_HIGHLIGHT_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 25
    IG_STORY_HIGHLIGHT_REACTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 26
    IG_EXTERNAL_LINK: ExtendedContentMessage.ExtendedContentType.ValueType  # 27
    IG_RECEIVER_FETCH: ExtendedContentMessage.ExtendedContentType.ValueType  # 28
    FB_FEED_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 1000
    FB_STORY_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 1001
    FB_STORY_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 1002
    FB_STORY_MENTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 1003
    FB_FEED_VIDEO_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 1004
    FB_GAMING_CUSTOM_UPDATE: ExtendedContentMessage.ExtendedContentType.ValueType  # 1005
    FB_PRODUCER_STORY_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 1006
    FB_EVENT: ExtendedContentMessage.ExtendedContentType.ValueType  # 1007
    FB_FEED_POST_PRIVATE_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 1008
    FB_SHORT: ExtendedContentMessage.ExtendedContentType.ValueType  # 1009
    FB_COMMENT_MENTION_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 1010
    FB_POST_MENTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 1011
    MSG_EXTERNAL_LINK_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2000
    MSG_P2P_PAYMENT: ExtendedContentMessage.ExtendedContentType.ValueType  # 2001
    MSG_LOCATION_SHARING: ExtendedContentMessage.ExtendedContentType.ValueType  # 2002
    MSG_LOCATION_SHARING_V2: ExtendedContentMessage.ExtendedContentType.ValueType  # 2003
    MSG_HIGHLIGHTS_TAB_FRIEND_UPDATES_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 2004
    MSG_HIGHLIGHTS_TAB_LOCAL_EVENT_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 2005
    MSG_RECEIVER_FETCH: ExtendedContentMessage.ExtendedContentType.ValueType  # 2006
    MSG_IG_MEDIA_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2007
    MSG_GEN_AI_SEARCH_PLUGIN_RESPONSE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2008
    MSG_REELS_LIST: ExtendedContentMessage.ExtendedContentType.ValueType  # 2009
    MSG_CONTACT: ExtendedContentMessage.ExtendedContentType.ValueType  # 2010
    MSG_THREADS_POST_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2011
    MSG_FILE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2012
    MSG_AVATAR_DETAILS: ExtendedContentMessage.ExtendedContentType.ValueType  # 2013
    MSG_AI_CONTACT: ExtendedContentMessage.ExtendedContentType.ValueType  # 2014
    MSG_MEMORIES_SHARE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2015
    MSG_SHARED_ALBUM_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 2016
    MSG_SHARED_ALBUM: ExtendedContentMessage.ExtendedContentType.ValueType  # 2017
    MSG_OCCAMADILLO_XMA: ExtendedContentMessage.ExtendedContentType.ValueType  # 2018
    MSG_GEN_AI_SUBSCRIPTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 2021
    MSG_GEN_AI_REMINDER: ExtendedContentMessage.ExtendedContentType.ValueType  # 2022
    MSG_GEN_AI_MEMU_ONBOARDING_RESPONSE: ExtendedContentMessage.ExtendedContentType.ValueType  # 2023
    MSG_NOTE_REPLY: ExtendedContentMessage.ExtendedContentType.ValueType  # 2024
    MSG_NOTE_MENTION: ExtendedContentMessage.ExtendedContentType.ValueType  # 2025
    RTC_AUDIO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3000
    RTC_VIDEO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3001
    RTC_MISSED_AUDIO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3002
    RTC_MISSED_VIDEO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3003
    RTC_GROUP_AUDIO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3004
    RTC_GROUP_VIDEO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3005
    RTC_MISSED_GROUP_AUDIO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3006
    RTC_MISSED_GROUP_VIDEO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3007
    RTC_ONGOING_AUDIO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3008
    RTC_ONGOING_VIDEO_CALL: ExtendedContentMessage.ExtendedContentType.ValueType  # 3009
    MSG_RECEIVER_FETCH_FALLBACK: ExtendedContentMessage.ExtendedContentType.ValueType  # 3025
    DATACLASS_SENDER_COPY: ExtendedContentMessage.ExtendedContentType.ValueType  # 4000

    @typing.final
    class CTA(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BUTTONTYPE_FIELD_NUMBER: builtins.int
        TITLE_FIELD_NUMBER: builtins.int
        ACTIONURL_FIELD_NUMBER: builtins.int
        NATIVEURL_FIELD_NUMBER: builtins.int
        CTATYPE_FIELD_NUMBER: builtins.int
        ACTIONCONTENTBLOB_FIELD_NUMBER: builtins.int
        buttonType: global___ExtendedContentMessage.CtaButtonType.ValueType
        title: builtins.str
        actionURL: builtins.str
        nativeURL: builtins.str
        ctaType: builtins.str
        actionContentBlob: builtins.str
        def __init__(
            self,
            *,
            buttonType: global___ExtendedContentMessage.CtaButtonType.ValueType | None = ...,
            title: builtins.str | None = ...,
            actionURL: builtins.str | None = ...,
            nativeURL: builtins.str | None = ...,
            ctaType: builtins.str | None = ...,
            actionContentBlob: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["actionContentBlob", b"actionContentBlob", "actionURL", b"actionURL", "buttonType", b"buttonType", "ctaType", b"ctaType", "nativeURL", b"nativeURL", "title", b"title"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["actionContentBlob", b"actionContentBlob", "actionURL", b"actionURL", "buttonType", b"buttonType", "ctaType", b"ctaType", "nativeURL", b"nativeURL", "title", b"title"]) -> None: ...

    ASSOCIATEDMESSAGE_FIELD_NUMBER: builtins.int
    TARGETTYPE_FIELD_NUMBER: builtins.int
    TARGETUSERNAME_FIELD_NUMBER: builtins.int
    TARGETID_FIELD_NUMBER: builtins.int
    TARGETEXPIRINGATSEC_FIELD_NUMBER: builtins.int
    XMALAYOUTTYPE_FIELD_NUMBER: builtins.int
    CTAS_FIELD_NUMBER: builtins.int
    PREVIEWS_FIELD_NUMBER: builtins.int
    TITLETEXT_FIELD_NUMBER: builtins.int
    SUBTITLETEXT_FIELD_NUMBER: builtins.int
    MAXTITLENUMOFLINES_FIELD_NUMBER: builtins.int
    MAXSUBTITLENUMOFLINES_FIELD_NUMBER: builtins.int
    FAVICON_FIELD_NUMBER: builtins.int
    HEADERIMAGE_FIELD_NUMBER: builtins.int
    HEADERTITLE_FIELD_NUMBER: builtins.int
    OVERLAYICONGLYPH_FIELD_NUMBER: builtins.int
    OVERLAYTITLE_FIELD_NUMBER: builtins.int
    OVERLAYDESCRIPTION_FIELD_NUMBER: builtins.int
    SENTWITHMESSAGEID_FIELD_NUMBER: builtins.int
    MESSAGETEXT_FIELD_NUMBER: builtins.int
    HEADERSUBTITLE_FIELD_NUMBER: builtins.int
    XMADATACLASS_FIELD_NUMBER: builtins.int
    CONTENTREF_FIELD_NUMBER: builtins.int
    MENTIONEDJID_FIELD_NUMBER: builtins.int
    COMMANDS_FIELD_NUMBER: builtins.int
    MENTIONS_FIELD_NUMBER: builtins.int
    targetType: global___ExtendedContentMessage.ExtendedContentType.ValueType
    targetUsername: builtins.str
    targetID: builtins.str
    targetExpiringAtSec: builtins.int
    xmaLayoutType: global___ExtendedContentMessage.XmaLayoutType.ValueType
    titleText: builtins.str
    subtitleText: builtins.str
    maxTitleNumOfLines: builtins.int
    maxSubtitleNumOfLines: builtins.int
    headerTitle: builtins.str
    overlayIconGlyph: global___ExtendedContentMessage.OverlayIconGlyph.ValueType
    overlayTitle: builtins.str
    overlayDescription: builtins.str
    sentWithMessageID: builtins.str
    messageText: builtins.str
    headerSubtitle: builtins.str
    xmaDataclass: builtins.str
    contentRef: builtins.str
    @property
    def associatedMessage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
    @property
    def ctas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExtendedContentMessage.CTA]: ...
    @property
    def previews(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[waCommon.WACommon_pb2.SubProtocol]: ...
    @property
    def favicon(self) -> waCommon.WACommon_pb2.SubProtocol: ...
    @property
    def headerImage(self) -> waCommon.WACommon_pb2.SubProtocol: ...
    @property
    def mentionedJID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def commands(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[waCommon.WACommon_pb2.Command]: ...
    @property
    def mentions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[waCommon.WACommon_pb2.Mention]: ...
    def __init__(
        self,
        *,
        associatedMessage: waCommon.WACommon_pb2.SubProtocol | None = ...,
        targetType: global___ExtendedContentMessage.ExtendedContentType.ValueType | None = ...,
        targetUsername: builtins.str | None = ...,
        targetID: builtins.str | None = ...,
        targetExpiringAtSec: builtins.int | None = ...,
        xmaLayoutType: global___ExtendedContentMessage.XmaLayoutType.ValueType | None = ...,
        ctas: collections.abc.Iterable[global___ExtendedContentMessage.CTA] | None = ...,
        previews: collections.abc.Iterable[waCommon.WACommon_pb2.SubProtocol] | None = ...,
        titleText: builtins.str | None = ...,
        subtitleText: builtins.str | None = ...,
        maxTitleNumOfLines: builtins.int | None = ...,
        maxSubtitleNumOfLines: builtins.int | None = ...,
        favicon: waCommon.WACommon_pb2.SubProtocol | None = ...,
        headerImage: waCommon.WACommon_pb2.SubProtocol | None = ...,
        headerTitle: builtins.str | None = ...,
        overlayIconGlyph: global___ExtendedContentMessage.OverlayIconGlyph.ValueType | None = ...,
        overlayTitle: builtins.str | None = ...,
        overlayDescription: builtins.str | None = ...,
        sentWithMessageID: builtins.str | None = ...,
        messageText: builtins.str | None = ...,
        headerSubtitle: builtins.str | None = ...,
        xmaDataclass: builtins.str | None = ...,
        contentRef: builtins.str | None = ...,
        mentionedJID: collections.abc.Iterable[builtins.str] | None = ...,
        commands: collections.abc.Iterable[waCommon.WACommon_pb2.Command] | None = ...,
        mentions: collections.abc.Iterable[waCommon.WACommon_pb2.Mention] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["associatedMessage", b"associatedMessage", "contentRef", b"contentRef", "favicon", b"favicon", "headerImage", b"headerImage", "headerSubtitle", b"headerSubtitle", "headerTitle", b"headerTitle", "maxSubtitleNumOfLines", b"maxSubtitleNumOfLines", "maxTitleNumOfLines", b"maxTitleNumOfLines", "messageText", b"messageText", "overlayDescription", b"overlayDescription", "overlayIconGlyph", b"overlayIconGlyph", "overlayTitle", b"overlayTitle", "sentWithMessageID", b"sentWithMessageID", "subtitleText", b"subtitleText", "targetExpiringAtSec", b"targetExpiringAtSec", "targetID", b"targetID", "targetType", b"targetType", "targetUsername", b"targetUsername", "titleText", b"titleText", "xmaDataclass", b"xmaDataclass", "xmaLayoutType", b"xmaLayoutType"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["associatedMessage", b"associatedMessage", "commands", b"commands", "contentRef", b"contentRef", "ctas", b"ctas", "favicon", b"favicon", "headerImage", b"headerImage", "headerSubtitle", b"headerSubtitle", "headerTitle", b"headerTitle", "maxSubtitleNumOfLines", b"maxSubtitleNumOfLines", "maxTitleNumOfLines", b"maxTitleNumOfLines", "mentionedJID", b"mentionedJID", "mentions", b"mentions", "messageText", b"messageText", "overlayDescription", b"overlayDescription", "overlayIconGlyph", b"overlayIconGlyph", "overlayTitle", b"overlayTitle", "previews", b"previews", "sentWithMessageID", b"sentWithMessageID", "subtitleText", b"subtitleText", "targetExpiringAtSec", b"targetExpiringAtSec", "targetID", b"targetID", "targetType", b"targetType", "targetUsername", b"targetUsername", "titleText", b"titleText", "xmaDataclass", b"xmaDataclass", "xmaLayoutType", b"xmaLayoutType"]) -> None: ...

global___ExtendedContentMessage = ExtendedContentMessage



import copy
from ..proto.Neonize_pb2 import JID


def JIDToNonAD(jid: JID) -> JID:
    """
    Converts a JID (Jabber ID) to a non-AD (Active Directory) format by setting RawAgent and Device to 0.

    :param jid: The JID to be converted.
    :type jid: JID
    :return: A new JID object with RawAgent and Device set to 0.
    :rtype: JID
    """
    new_jid = copy.deepcopy(jid)
    new_jid.RawAgent = 0
    new_jid.Device = 0
    return new_jid


def Jid2String(jid: JID) -> str:
    """Converts a Jabber Identifier (JID) to a string.

    :param jid: The Jabber Identifier (JID) to be converted.
    :type jid: JID
    :return: The string representation of the JID.
    :rtype: str
    """
    if jid.RawAgent > 0:
        return "%s.%s:%d@%s" % (jid.User, jid.RawAgent, jid.Device, jid.Server)
    elif jid.Device > 0:
        return "%s:%d@%s" % (jid.User, jid.Device, jid.Server)
    elif len(jid.User) > 0:
        return "%s@%s" % (jid.User, jid.Server)
    return jid.Server


def build_jid(phone_number: str, server: str = "s.whatsapp.net") -> JID:
    """
    Builds a JID (Jabber ID) from a phone number.

    :param phone_number: The phone number to be used for building the JID.
    :type phone_number: str
    :return: A JID object constructed from the given phone number.
    :rtype: JID
    """
    return JID(
        User=phone_number,
        Device=0,
        Integrator=0,
        IsEmpty=False,
        RawAgent=0,
        Server=server,
    )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UserPassword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Transformer:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TransformerEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserPassword._Transformer.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: UserPassword._Transformer.ValueType  # 0
        PBKDF2_HMAC_SHA512: UserPassword._Transformer.ValueType  # 1
        PBKDF2_HMAC_SHA384: UserPassword._Transformer.ValueType  # 2

    class Transformer(_Transformer, metaclass=_TransformerEnumTypeWrapper): ...
    NONE: UserPassword.Transformer.ValueType  # 0
    PBKDF2_HMAC_SHA512: UserPassword.Transformer.ValueType  # 1
    PBKDF2_HMAC_SHA384: UserPassword.Transformer.ValueType  # 2

    class _Encoding:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EncodingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UserPassword._Encoding.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UTF8: UserPassword._Encoding.ValueType  # 0
        UTF8_BROKEN: UserPassword._Encoding.ValueType  # 1

    class Encoding(_Encoding, metaclass=_EncodingEnumTypeWrapper): ...
    UTF8: UserPassword.Encoding.ValueType  # 0
    UTF8_BROKEN: UserPassword.Encoding.ValueType  # 1

    @typing.final
    class TransformerArg(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Value(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            ASBLOB_FIELD_NUMBER: builtins.int
            ASUNSIGNEDINTEGER_FIELD_NUMBER: builtins.int
            asBlob: builtins.bytes
            asUnsignedInteger: builtins.int
            def __init__(
                self,
                *,
                asBlob: builtins.bytes | None = ...,
                asUnsignedInteger: builtins.int | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["asBlob", b"asBlob", "asUnsignedInteger", b"asUnsignedInteger", "value", b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["asBlob", b"asBlob", "asUnsignedInteger", b"asUnsignedInteger", "value", b"value"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["asBlob", "asUnsignedInteger"] | None: ...

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___UserPassword.TransformerArg.Value: ...
        def __init__(
            self,
            *,
            key: builtins.str | None = ...,
            value: global___UserPassword.TransformerArg.Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENCODING_FIELD_NUMBER: builtins.int
    TRANSFORMER_FIELD_NUMBER: builtins.int
    TRANSFORMERARG_FIELD_NUMBER: builtins.int
    TRANSFORMEDDATA_FIELD_NUMBER: builtins.int
    encoding: global___UserPassword.Encoding.ValueType
    transformer: global___UserPassword.Transformer.ValueType
    transformedData: builtins.bytes
    @property
    def transformerArg(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserPassword.TransformerArg]: ...
    def __init__(
        self,
        *,
        encoding: global___UserPassword.Encoding.ValueType | None = ...,
        transformer: global___UserPassword.Transformer.ValueType | None = ...,
        transformerArg: collections.abc.Iterable[global___UserPassword.TransformerArg] | None = ...,
        transformedData: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["encoding", b"encoding", "transformedData", b"transformedData", "transformer", b"transformer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["encoding", b"encoding", "transformedData", b"transformedData", "transformer", b"transformer", "transformerArg", b"transformerArg"]) -> None: ...

global___UserPassword = UserPassword



import os
from .utils.platform import generated_name
import requests
from pathlib import Path
from tqdm import tqdm
__GONEONIZE_VERSION__ = '0.3.10.6'
__GIT_RELEASE_URL__ = 'https://github.com/krypton-byte/neonize'

class UnsupportedPlatform(Exception):
    pass

def __download(url: str, fname: str, chunk_size=1024):
    resp = requests.get(url, stream=True)
    if resp.status_code != 200:
        resp.close()
        raise UnsupportedPlatform(generated_name())
    total = int(resp.headers.get('content-length', 0))
    with open(fname, 'wb') as file, tqdm(desc=Path(fname).name, total=total, unit='iB', unit_scale=True, unit_divisor=1024) as bar:
        for data in resp.iter_content(chunk_size=chunk_size):
            size = file.write(data)
            bar.update(size)
        bar.n = total
    bar.close()

def download():
    __download(f'{__GIT_RELEASE_URL__}/releases/download/{__GONEONIZE_VERSION__}/{generated_name()}', f'{os.path.dirname(__file__)}/{generated_name()}')
if __name__ == '__main__':
    download()


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloBackupMessage/WAArmadilloBackupMessage.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waArmadilloBackupMessage/WAArmadilloBackupMessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waArmadilloBackupCommon import WAArmadilloBackupCommon_pb2 as waArmadilloBackupCommon_dot_WAArmadilloBackupCommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7waArmadilloBackupMessage/WAArmadilloBackupMessage.proto\x12\x18WAArmadilloBackupMessage\x1a\x35waArmadilloBackupCommon/WAArmadilloBackupCommon.proto\"\xa1\x05\n\rBackupMessage\x12#\n\x19\x65ncryptedTransportMessage\x18\x02 \x01(\x0cH\x00\x12G\n\x17\x65ncryptedTransportEvent\x18\x05 \x01(\x0b\x32$.WAArmadilloBackupCommon.SubprotocolH\x00\x12[\n+encryptedTransportLocallyTransformedMessage\x18\x06 \x01(\x0b\x32$.WAArmadilloBackupCommon.SubprotocolH\x00\x12G\n\x17miTransportAdminMessage\x18\x07 \x01(\x0b\x32$.WAArmadilloBackupCommon.SubprotocolH\x00\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.WAArmadilloBackupMessage.BackupMessage.Metadata\x1a\xac\x02\n\x08Metadata\x12\x10\n\x08senderID\x18\x01 \x01(\t\x12\x11\n\tmessageID\x18\x02 \x01(\t\x12\x13\n\x0btimestampMS\x18\x03 \x01(\x03\x12[\n\x10\x66rankingMetadata\x18\x04 \x01(\x0b\x32\x41.WAArmadilloBackupMessage.BackupMessage.Metadata.FrankingMetadata\x12\x16\n\x0epayloadVersion\x18\x05 \x01(\x05\x12\x1b\n\x13\x66utureProofBehavior\x18\x06 \x01(\x05\x12\x15\n\rthreadTypeTag\x18\x07 \x01(\x05\x1a=\n\x10\x46rankingMetadata\x12\x13\n\x0b\x66rankingTag\x18\x03 \x01(\x0c\x12\x14\n\x0creportingTag\x18\x04 \x01(\x0c\x42\t\n\x07payloadB4Z2go.mau.fi/whatsmeow/proto/waArmadilloBackupMessage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloBackupMessage.WAArmadilloBackupMessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2go.mau.fi/whatsmeow/proto/waArmadilloBackupMessage'
  _globals['_BACKUPMESSAGE']._serialized_start=141
  _globals['_BACKUPMESSAGE']._serialized_end=814
  _globals['_BACKUPMESSAGE_METADATA']._serialized_start=503
  _globals['_BACKUPMESSAGE_METADATA']._serialized_end=803
  _globals['_BACKUPMESSAGE_METADATA_FRANKINGMETADATA']._serialized_start=742
  _globals['_BACKUPMESSAGE_METADATA_FRANKINGMETADATA']._serialized_end=803
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloMiTransportAdminMessage/WAArmadilloMiTransportAdminMessage.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waArmadilloMiTransportAdminMessage/WAArmadilloMiTransportAdminMessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKwaArmadilloMiTransportAdminMessage/WAArmadilloMiTransportAdminMessage.proto\x12\"WAArmadilloMiTransportAdminMessage\"\xce\x15\n\x17MiTransportAdminMessage\x12h\n\x10\x63hatThemeChanged\x18\x01 \x01(\x0b\x32L.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.ChatThemeChangedH\x00\x12\x66\n\x0fnicknameChanged\x18\x02 \x01(\x0b\x32K.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.NicknameChangedH\x00\x12v\n\x17groupParticipantChanged\x18\x03 \x01(\x0b\x32S.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupParticipantChangedH\x00\x12j\n\x11groupAdminChanged\x18\x04 \x01(\x0b\x32M.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupAdminChangedH\x00\x12h\n\x10groupNameChanged\x18\x05 \x01(\x0b\x32L.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupNameChangedH\x00\x12\x82\x01\n\x1dgroupMembershipAddModeChanged\x18\x06 \x01(\x0b\x32Y.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupMembershipAddModeChangedH\x00\x12\x62\n\rmessagePinned\x18\x07 \x01(\x0b\x32I.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.MessagePinnedH\x00\x12j\n\x11groupImageChanged\x18\x08 \x01(\x0b\x32M.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupImageChangedH\x00\x12p\n\x14quickReactionChanged\x18\t \x01(\x0b\x32P.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.QuickReactionChangedH\x00\x12V\n\x07linkCta\x18\n \x01(\x0b\x32\x43.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.LinkCtaH\x00\x12^\n\x0biconChanged\x18\x0b \x01(\x0b\x32G.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.IconChangedH\x00\x12|\n\x1a\x64isappearingSettingChanged\x18\x0c \x01(\x0b\x32V.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.DisappearingSettingChangedH\x00\x1a\x9d\x01\n\x11GroupImageChanged\x12\x64\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32T.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupImageChanged.Action\"\"\n\x06\x41\x63tion\x12\x0b\n\x07\x43HANGED\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x1a\x95\x01\n\rMessagePinned\x12`\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32P.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.MessagePinned.Action\"\"\n\x06\x41\x63tion\x12\n\n\x06PINNED\x10\x01\x12\x0c\n\x08UNPINNED\x10\x02\x1a\xb7\x01\n\x1dGroupMembershipAddModeChanged\x12l\n\x04mode\x18\x01 \x01(\x0e\x32^.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode\"(\n\x04Mode\x12\x0f\n\x0b\x41LL_MEMBERS\x10\x01\x12\x0f\n\x0b\x41\x44MINS_ONLY\x10\x02\x1a\xb1\x01\n\x11GroupAdminChanged\x12\x14\n\x0ctargetUserID\x18\x01 \x03(\t\x12\x64\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32T.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupAdminChanged.Action\" \n\x06\x41\x63tion\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x1a\xbd\x01\n\x17GroupParticipantChanged\x12\x14\n\x0ctargetUserID\x18\x01 \x03(\t\x12j\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32Z.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.GroupParticipantChanged.Action\" \n\x06\x41\x63tion\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x1aw\n\x1a\x44isappearingSettingChanged\x12*\n\"disappearingSettingDurationSeconds\x18\x01 \x01(\x05\x12-\n%oldDisappearingSettingDurationSeconds\x18\x02 \x01(\x05\x1a!\n\x0bIconChanged\x12\x12\n\nthreadIcon\x18\x01 \x01(\t\x1a\xad\x01\n\x07LinkCta\x12l\n\x0eukOsaAdminText\x18\x01 \x01(\x0b\x32R.WAArmadilloMiTransportAdminMessage.MiTransportAdminMessage.LinkCta.UkOsaAdminTextH\x00\x1a)\n\x0eUkOsaAdminText\x12\x17\n\x0finitiatorUserID\x18\x02 \x01(\tB\t\n\x07\x63ontent\x1a)\n\x14QuickReactionChanged\x12\x11\n\temojiName\x18\x01 \x01(\t\x1a%\n\x10GroupNameChanged\x12\x11\n\tgroupName\x18\x01 \x01(\t\x1a\x39\n\x0fNicknameChanged\x12\x14\n\x0ctargetUserID\x18\x01 \x01(\t\x12\x10\n\x08nickname\x18\x02 \x01(\t\x1aL\n\x10\x43hatThemeChanged\x12\x11\n\tthemeName\x18\x01 \x01(\t\x12\x12\n\nthemeEmoji\x18\x02 \x01(\t\x12\x11\n\tthemeType\x18\x03 \x01(\x05\x42\t\n\x07\x63ontentB>Z<go.mau.fi/whatsmeow/proto/waArmadilloMiTransportAdminMessage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloMiTransportAdminMessage.WAArmadilloMiTransportAdminMessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<go.mau.fi/whatsmeow/proto/waArmadilloMiTransportAdminMessage'
  _globals['_MITRANSPORTADMINMESSAGE']._serialized_start=116
  _globals['_MITRANSPORTADMINMESSAGE']._serialized_end=2882
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED']._serialized_start=1453
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED']._serialized_end=1610
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED_ACTION']._serialized_start=1576
  _globals['_MITRANSPORTADMINMESSAGE_GROUPIMAGECHANGED_ACTION']._serialized_end=1610
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED']._serialized_start=1613
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED']._serialized_end=1762
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED_ACTION']._serialized_start=1728
  _globals['_MITRANSPORTADMINMESSAGE_MESSAGEPINNED_ACTION']._serialized_end=1762
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED']._serialized_start=1765
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED']._serialized_end=1948
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED_MODE']._serialized_start=1908
  _globals['_MITRANSPORTADMINMESSAGE_GROUPMEMBERSHIPADDMODECHANGED_MODE']._serialized_end=1948
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED']._serialized_start=1951
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED']._serialized_end=2128
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED_ACTION']._serialized_start=2096
  _globals['_MITRANSPORTADMINMESSAGE_GROUPADMINCHANGED_ACTION']._serialized_end=2128
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED']._serialized_start=2131
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED']._serialized_end=2320
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED_ACTION']._serialized_start=2096
  _globals['_MITRANSPORTADMINMESSAGE_GROUPPARTICIPANTCHANGED_ACTION']._serialized_end=2128
  _globals['_MITRANSPORTADMINMESSAGE_DISAPPEARINGSETTINGCHANGED']._serialized_start=2322
  _globals['_MITRANSPORTADMINMESSAGE_DISAPPEARINGSETTINGCHANGED']._serialized_end=2441
  _globals['_MITRANSPORTADMINMESSAGE_ICONCHANGED']._serialized_start=2443
  _globals['_MITRANSPORTADMINMESSAGE_ICONCHANGED']._serialized_end=2476
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA']._serialized_start=2479
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA']._serialized_end=2652
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA_UKOSAADMINTEXT']._serialized_start=2600
  _globals['_MITRANSPORTADMINMESSAGE_LINKCTA_UKOSAADMINTEXT']._serialized_end=2641
  _globals['_MITRANSPORTADMINMESSAGE_QUICKREACTIONCHANGED']._serialized_start=2654
  _globals['_MITRANSPORTADMINMESSAGE_QUICKREACTIONCHANGED']._serialized_end=2695
  _globals['_MITRANSPORTADMINMESSAGE_GROUPNAMECHANGED']._serialized_start=2697
  _globals['_MITRANSPORTADMINMESSAGE_GROUPNAMECHANGED']._serialized_end=2734
  _globals['_MITRANSPORTADMINMESSAGE_NICKNAMECHANGED']._serialized_start=2736
  _globals['_MITRANSPORTADMINMESSAGE_NICKNAMECHANGED']._serialized_end=2793
  _globals['_MITRANSPORTADMINMESSAGE_CHATTHEMECHANGED']._serialized_start=2795
  _globals['_MITRANSPORTADMINMESSAGE_CHATTHEMECHANGED']._serialized_end=2871
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waRoutingInfo/WAWebProtobufsRoutingInfo.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waRoutingInfo/WAWebProtobufsRoutingInfo.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-waRoutingInfo/WAWebProtobufsRoutingInfo.proto\x12\x19WAWebProtobufsRoutingInfo\"w\n\x0bRoutingInfo\x12\x10\n\x08regionID\x18\x01 \x03(\x05\x12\x11\n\tclusterID\x18\x02 \x03(\x05\x12\x0e\n\x06taskID\x18\x03 \x01(\x05\x12\r\n\x05\x64\x65\x62ug\x18\x04 \x01(\x08\x12\x0e\n\x06tcpBbr\x18\x05 \x01(\x08\x12\x14\n\x0ctcpKeepalive\x18\x06 \x01(\x08\x42)Z\'go.mau.fi/whatsmeow/proto/waRoutingInfo')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waRoutingInfo.WAWebProtobufsRoutingInfo_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'go.mau.fi/whatsmeow/proto/waRoutingInfo'
  _globals['_ROUTINGINFO']._serialized_start=76
  _globals['_ROUTINGINFO']._serialized_end=195
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RoutingInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGIONID_FIELD_NUMBER: builtins.int
    CLUSTERID_FIELD_NUMBER: builtins.int
    TASKID_FIELD_NUMBER: builtins.int
    DEBUG_FIELD_NUMBER: builtins.int
    TCPBBR_FIELD_NUMBER: builtins.int
    TCPKEEPALIVE_FIELD_NUMBER: builtins.int
    taskID: builtins.int
    debug: builtins.bool
    tcpBbr: builtins.bool
    tcpKeepalive: builtins.bool
    @property
    def regionID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def clusterID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        regionID: collections.abc.Iterable[builtins.int] | None = ...,
        clusterID: collections.abc.Iterable[builtins.int] | None = ...,
        taskID: builtins.int | None = ...,
        debug: builtins.bool | None = ...,
        tcpBbr: builtins.bool | None = ...,
        tcpKeepalive: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["debug", b"debug", "taskID", b"taskID", "tcpBbr", b"tcpBbr", "tcpKeepalive", b"tcpKeepalive"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clusterID", b"clusterID", "debug", b"debug", "regionID", b"regionID", "taskID", b"taskID", "tcpBbr", b"tcpBbr", "tcpKeepalive", b"tcpKeepalive"]) -> None: ...

global___RoutingInfo = RoutingInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waWinUIApi/WAWinUIApi.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waWinUIApi/WAWinUIApi.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bwaWinUIApi/WAWinUIApi.proto\x12\nWAWinUIApi\"\xa7\x02\n\x0fPositronMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12.\n\x02ID\x18\x04 \x01(\x0b\x32\".WAWinUIApi.PositronMessage.MsgKey\x12\x0c\n\x04JSON\x18\x63 \x01(\t\x1a\x8b\x01\n\x06MsgKey\x12\x0e\n\x06\x66romMe\x18\x01 \x01(\x08\x12/\n\x06remote\x18\x02 \x01(\x0b\x32\x1f.WAWinUIApi.PositronMessage.WID\x12\n\n\x02ID\x18\x03 \x01(\t\x12\x34\n\x0bparticipant\x18\x04 \x01(\x0b\x32\x1f.WAWinUIApi.PositronMessage.WID\x1a\x19\n\x03WID\x12\x12\n\nserialized\x18\x01 \x01(\t\"^\n\x0cPositronChat\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x13\n\x0bunreadCount\x18\x04 \x01(\x03\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"l\n\x0fPositronContact\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x13\n\x0bphoneNumber\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14isAddressBookContact\x18\x04 \x01(\x08\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"B\n\x15PositronGroupMetadata\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"K\n\x19PositronGroupParticipants\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x14\n\x0cparticipants\x18\x02 \x03(\t\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"\x82\x01\n\x10PositronReaction\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x14\n\x0cparentMsgKey\x18\x02 \x01(\t\x12\x14\n\x0creactionText\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\x15\n\rsenderUserJID\x18\x05 \x01(\t\x12\x0c\n\x04JSON\x18\x63 \x01(\t\"\xf6\x02\n\x0cPositronData\x12\x32\n\ndataSource\x18\x01 \x01(\x0e\x32\x1e.WAWinUIApi.PositronDataSource\x12-\n\x08messages\x18\x02 \x03(\x0b\x32\x1b.WAWinUIApi.PositronMessage\x12\'\n\x05\x63hats\x18\x03 \x03(\x0b\x32\x18.WAWinUIApi.PositronChat\x12-\n\x08\x63ontacts\x18\x04 \x03(\x0b\x32\x1b.WAWinUIApi.PositronContact\x12\x38\n\rgroupMetadata\x18\x05 \x03(\x0b\x32!.WAWinUIApi.PositronGroupMetadata\x12@\n\x11groupParticipants\x18\x06 \x03(\x0b\x32%.WAWinUIApi.PositronGroupParticipants\x12/\n\treactions\x18\x07 \x03(\x0b\x32\x1c.WAWinUIApi.PositronReaction*v\n\x12PositronDataSource\x12\x0c\n\x08MESSAGES\x10\x01\x12\t\n\x05\x43HATS\x10\x02\x12\x0c\n\x08\x43ONTACTS\x10\x03\x12\x12\n\x0eGROUP_METADATA\x10\x04\x12\x16\n\x12GROUP_PARTICIPANTS\x10\x05\x12\r\n\tREACTIONS\x10\x06\x42&Z$go.mau.fi/whatsmeow/proto/waWinUIApi')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waWinUIApi.WAWinUIApi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$go.mau.fi/whatsmeow/proto/waWinUIApi'
  _globals['_POSITRONDATASOURCE']._serialized_start=1202
  _globals['_POSITRONDATASOURCE']._serialized_end=1320
  _globals['_POSITRONMESSAGE']._serialized_start=44
  _globals['_POSITRONMESSAGE']._serialized_end=339
  _globals['_POSITRONMESSAGE_MSGKEY']._serialized_start=173
  _globals['_POSITRONMESSAGE_MSGKEY']._serialized_end=312
  _globals['_POSITRONMESSAGE_WID']._serialized_start=314
  _globals['_POSITRONMESSAGE_WID']._serialized_end=339
  _globals['_POSITRONCHAT']._serialized_start=341
  _globals['_POSITRONCHAT']._serialized_end=435
  _globals['_POSITRONCONTACT']._serialized_start=437
  _globals['_POSITRONCONTACT']._serialized_end=545
  _globals['_POSITRONGROUPMETADATA']._serialized_start=547
  _globals['_POSITRONGROUPMETADATA']._serialized_end=613
  _globals['_POSITRONGROUPPARTICIPANTS']._serialized_start=615
  _globals['_POSITRONGROUPPARTICIPANTS']._serialized_end=690
  _globals['_POSITRONREACTION']._serialized_start=693
  _globals['_POSITRONREACTION']._serialized_end=823
  _globals['_POSITRONDATA']._serialized_start=826
  _globals['_POSITRONDATA']._serialized_end=1200
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waCommon/WACommon.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waCommon/WACommon.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17waCommon/WACommon.proto\x12\x08WACommon\"P\n\nMessageKey\x12\x11\n\tremoteJID\x18\x01 \x01(\t\x12\x0e\n\x06\x66romMe\x18\x02 \x01(\x08\x12\n\n\x02ID\x18\x03 \x01(\t\x12\x13\n\x0bparticipant\x18\x04 \x01(\t\"\xb7\x01\n\x07\x43ommand\x12\x32\n\x0b\x63ommandType\x18\x01 \x01(\x0e\x32\x1d.WACommon.Command.CommandType\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x0e\n\x06length\x18\x03 \x01(\r\x12\x17\n\x0fvalidationToken\x18\x04 \x01(\t\"?\n\x0b\x43ommandType\x12\x0c\n\x08\x45VERYONE\x10\x01\x12\n\n\x06SILENT\x10\x02\x12\x06\n\x02\x41I\x10\x03\x12\x0e\n\nAI_IMAGINE\x10\x04\"\x8f\x01\n\x07Mention\x12\x32\n\x0bmentionType\x18\x01 \x01(\x0e\x32\x1d.WACommon.Mention.MentionType\x12\x14\n\x0cmentionedJID\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\r\x12\x0e\n\x06length\x18\x04 \x01(\r\"\x1a\n\x0bMentionType\x12\x0b\n\x07PROFILE\x10\x00\"{\n\x0bMessageText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x14\n\x0cmentionedJID\x18\x02 \x03(\t\x12#\n\x08\x63ommands\x18\x03 \x03(\x0b\x32\x11.WACommon.Command\x12#\n\x08mentions\x18\x04 \x03(\x0b\x32\x11.WACommon.Mention\"/\n\x0bSubProtocol\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x0f\n\x07version\x18\x02 \x01(\x05\"\xee\x01\n\x0cLimitSharing\x12\x16\n\x0esharingLimited\x18\x01 \x01(\x08\x12/\n\x07trigger\x18\x02 \x01(\x0e\x32\x1e.WACommon.LimitSharing.Trigger\x12$\n\x1climitSharingSettingTimestamp\x18\x03 \x01(\x03\x12\x15\n\rinitiatedByMe\x18\x04 \x01(\x08\"X\n\x07Trigger\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0c\x43HAT_SETTING\x10\x01\x12\x1b\n\x17\x42IZ_SUPPORTS_FB_HOSTING\x10\x02\x12\x11\n\rUNKNOWN_GROUP\x10\x03*F\n\x13\x46utureProofBehavior\x12\x0f\n\x0bPLACEHOLDER\x10\x00\x12\x12\n\x0eNO_PLACEHOLDER\x10\x01\x12\n\n\x06IGNORE\x10\x02\x42$Z\"go.mau.fi/whatsmeow/proto/waCommon')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waCommon.WACommon_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\"go.mau.fi/whatsmeow/proto/waCommon'
  _globals['_FUTUREPROOFBEHAVIOR']._serialized_start=866
  _globals['_FUTUREPROOFBEHAVIOR']._serialized_end=936
  _globals['_MESSAGEKEY']._serialized_start=37
  _globals['_MESSAGEKEY']._serialized_end=117
  _globals['_COMMAND']._serialized_start=120
  _globals['_COMMAND']._serialized_end=303
  _globals['_COMMAND_COMMANDTYPE']._serialized_start=240
  _globals['_COMMAND_COMMANDTYPE']._serialized_end=303
  _globals['_MENTION']._serialized_start=306
  _globals['_MENTION']._serialized_end=449
  _globals['_MENTION_MENTIONTYPE']._serialized_start=423
  _globals['_MENTION_MENTIONTYPE']._serialized_end=449
  _globals['_MESSAGETEXT']._serialized_start=451
  _globals['_MESSAGETEXT']._serialized_end=574
  _globals['_SUBPROTOCOL']._serialized_start=576
  _globals['_SUBPROTOCOL']._serialized_end=623
  _globals['_LIMITSHARING']._serialized_start=626
  _globals['_LIMITSHARING']._serialized_end=864
  _globals['_LIMITSHARING_TRIGGER']._serialized_start=776
  _globals['_LIMITSHARING_TRIGGER']._serialized_end=864
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloXMA/WAArmadilloXMA.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waArmadilloXMA/WAArmadilloXMA.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#waArmadilloXMA/WAArmadilloXMA.proto\x12\x0eWAArmadilloXMA\x1a\x17waCommon/WACommon.proto\"\xb7\x19\n\x16\x45xtendedContentMessage\x12\x30\n\x11\x61ssociatedMessage\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12N\n\ntargetType\x18\x02 \x01(\x0e\x32:.WAArmadilloXMA.ExtendedContentMessage.ExtendedContentType\x12\x16\n\x0etargetUsername\x18\x03 \x01(\t\x12\x10\n\x08targetID\x18\x04 \x01(\t\x12\x1b\n\x13targetExpiringAtSec\x18\x05 \x01(\x03\x12K\n\rxmaLayoutType\x18\x06 \x01(\x0e\x32\x34.WAArmadilloXMA.ExtendedContentMessage.XmaLayoutType\x12\x38\n\x04\x63tas\x18\x07 \x03(\x0b\x32*.WAArmadilloXMA.ExtendedContentMessage.CTA\x12\'\n\x08previews\x18\x08 \x03(\x0b\x32\x15.WACommon.SubProtocol\x12\x11\n\ttitleText\x18\t \x01(\t\x12\x14\n\x0csubtitleText\x18\n \x01(\t\x12\x1a\n\x12maxTitleNumOfLines\x18\x0b \x01(\r\x12\x1d\n\x15maxSubtitleNumOfLines\x18\x0c \x01(\r\x12&\n\x07\x66\x61vicon\x18\r \x01(\x0b\x32\x15.WACommon.SubProtocol\x12*\n\x0bheaderImage\x18\x0e \x01(\x0b\x32\x15.WACommon.SubProtocol\x12\x13\n\x0bheaderTitle\x18\x0f \x01(\t\x12Q\n\x10overlayIconGlyph\x18\x10 \x01(\x0e\x32\x37.WAArmadilloXMA.ExtendedContentMessage.OverlayIconGlyph\x12\x14\n\x0coverlayTitle\x18\x11 \x01(\t\x12\x1a\n\x12overlayDescription\x18\x12 \x01(\t\x12\x19\n\x11sentWithMessageID\x18\x13 \x01(\t\x12\x13\n\x0bmessageText\x18\x14 \x01(\t\x12\x16\n\x0eheaderSubtitle\x18\x15 \x01(\t\x12\x14\n\x0cxmaDataclass\x18\x16 \x01(\t\x12\x12\n\ncontentRef\x18\x17 \x01(\t\x12\x14\n\x0cmentionedJID\x18\x18 \x03(\t\x12#\n\x08\x63ommands\x18\x19 \x03(\x0b\x32\x11.WACommon.Command\x12#\n\x08mentions\x18\x1a \x03(\x0b\x32\x11.WACommon.Mention\x1a\xb0\x01\n\x03\x43TA\x12H\n\nbuttonType\x18\x01 \x01(\x0e\x32\x34.WAArmadilloXMA.ExtendedContentMessage.CtaButtonType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\tactionURL\x18\x03 \x01(\t\x12\x11\n\tnativeURL\x18\x04 \x01(\t\x12\x0f\n\x07\x63taType\x18\x05 \x01(\t\x12\x19\n\x11\x61\x63tionContentBlob\x18\x06 \x01(\t\"\xa1\x01\n\x10OverlayIconGlyph\x12\x08\n\x04INFO\x10\x00\x12\x0b\n\x07\x45YE_OFF\x10\x01\x12\x0c\n\x08NEWS_OFF\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\x0b\n\x07PRIVATE\x10\x04\x12\x08\n\x04NONE\x10\x05\x12\x0f\n\x0bMEDIA_LABEL\x10\x06\x12\x0e\n\nPOST_COVER\x10\x07\x12\x0e\n\nPOST_LABEL\x10\x08\x12\x13\n\x0fWARNING_SCREENS\x10\t\" \n\rCtaButtonType\x12\x0f\n\x0bOPEN_NATIVE\x10\x0b\"b\n\rXmaLayoutType\x12\n\n\x06SINGLE\x10\x00\x12\x0b\n\x07HSCROLL\x10\x01\x12\x0c\n\x08PORTRAIT\x10\x03\x12\x11\n\rSTANDARD_DXMA\x10\x0c\x12\r\n\tLIST_DXMA\x10\x0f\x12\x08\n\x04GRID\x10\x10\"\xa2\x0e\n\x13\x45xtendedContentType\x12\x0f\n\x0bUNSUPPORTED\x10\x00\x12\x1a\n\x16IG_STORY_PHOTO_MENTION\x10\x04\x12\x1e\n\x1aIG_SINGLE_IMAGE_POST_SHARE\x10\t\x12\x16\n\x12IG_MULTIPOST_SHARE\x10\n\x12\x1e\n\x1aIG_SINGLE_VIDEO_POST_SHARE\x10\x0b\x12\x18\n\x14IG_STORY_PHOTO_SHARE\x10\x0c\x12\x18\n\x14IG_STORY_VIDEO_SHARE\x10\r\x12\x12\n\x0eIG_CLIPS_SHARE\x10\x0e\x12\x11\n\rIG_IGTV_SHARE\x10\x0f\x12\x11\n\rIG_SHOP_SHARE\x10\x10\x12\x14\n\x10IG_PROFILE_SHARE\x10\x13\x12\"\n\x1eIG_STORY_PHOTO_HIGHLIGHT_SHARE\x10\x14\x12\"\n\x1eIG_STORY_VIDEO_HIGHLIGHT_SHARE\x10\x15\x12\x12\n\x0eIG_STORY_REPLY\x10\x16\x12\x15\n\x11IG_STORY_REACTION\x10\x17\x12\x1a\n\x16IG_STORY_VIDEO_MENTION\x10\x18\x12\x1c\n\x18IG_STORY_HIGHLIGHT_REPLY\x10\x19\x12\x1f\n\x1bIG_STORY_HIGHLIGHT_REACTION\x10\x1a\x12\x14\n\x10IG_EXTERNAL_LINK\x10\x1b\x12\x15\n\x11IG_RECEIVER_FETCH\x10\x1c\x12\x12\n\rFB_FEED_SHARE\x10\xe8\x07\x12\x13\n\x0e\x46\x42_STORY_REPLY\x10\xe9\x07\x12\x13\n\x0e\x46\x42_STORY_SHARE\x10\xea\x07\x12\x15\n\x10\x46\x42_STORY_MENTION\x10\xeb\x07\x12\x18\n\x13\x46\x42_FEED_VIDEO_SHARE\x10\xec\x07\x12\x1c\n\x17\x46\x42_GAMING_CUSTOM_UPDATE\x10\xed\x07\x12\x1c\n\x17\x46\x42_PRODUCER_STORY_REPLY\x10\xee\x07\x12\r\n\x08\x46\x42_EVENT\x10\xef\x07\x12\x1f\n\x1a\x46\x42_FEED_POST_PRIVATE_REPLY\x10\xf0\x07\x12\r\n\x08\x46\x42_SHORT\x10\xf1\x07\x12\x1d\n\x18\x46\x42_COMMENT_MENTION_SHARE\x10\xf2\x07\x12\x14\n\x0f\x46\x42_POST_MENTION\x10\xf3\x07\x12\x1c\n\x17MSG_EXTERNAL_LINK_SHARE\x10\xd0\x0f\x12\x14\n\x0fMSG_P2P_PAYMENT\x10\xd1\x0f\x12\x19\n\x14MSG_LOCATION_SHARING\x10\xd2\x0f\x12\x1c\n\x17MSG_LOCATION_SHARING_V2\x10\xd3\x0f\x12,\n\'MSG_HIGHLIGHTS_TAB_FRIEND_UPDATES_REPLY\x10\xd4\x0f\x12)\n$MSG_HIGHLIGHTS_TAB_LOCAL_EVENT_REPLY\x10\xd5\x0f\x12\x17\n\x12MSG_RECEIVER_FETCH\x10\xd6\x0f\x12\x17\n\x12MSG_IG_MEDIA_SHARE\x10\xd7\x0f\x12&\n!MSG_GEN_AI_SEARCH_PLUGIN_RESPONSE\x10\xd8\x0f\x12\x13\n\x0eMSG_REELS_LIST\x10\xd9\x0f\x12\x10\n\x0bMSG_CONTACT\x10\xda\x0f\x12\x1b\n\x16MSG_THREADS_POST_SHARE\x10\xdb\x0f\x12\r\n\x08MSG_FILE\x10\xdc\x0f\x12\x17\n\x12MSG_AVATAR_DETAILS\x10\xdd\x0f\x12\x13\n\x0eMSG_AI_CONTACT\x10\xde\x0f\x12\x17\n\x12MSG_MEMORIES_SHARE\x10\xdf\x0f\x12\x1b\n\x16MSG_SHARED_ALBUM_REPLY\x10\xe0\x0f\x12\x15\n\x10MSG_SHARED_ALBUM\x10\xe1\x0f\x12\x18\n\x13MSG_OCCAMADILLO_XMA\x10\xe2\x0f\x12\x1c\n\x17MSG_GEN_AI_SUBSCRIPTION\x10\xe5\x0f\x12\x18\n\x13MSG_GEN_AI_REMINDER\x10\xe6\x0f\x12(\n#MSG_GEN_AI_MEMU_ONBOARDING_RESPONSE\x10\xe7\x0f\x12\x13\n\x0eMSG_NOTE_REPLY\x10\xe8\x0f\x12\x15\n\x10MSG_NOTE_MENTION\x10\xe9\x0f\x12\x13\n\x0eRTC_AUDIO_CALL\x10\xb8\x17\x12\x13\n\x0eRTC_VIDEO_CALL\x10\xb9\x17\x12\x1a\n\x15RTC_MISSED_AUDIO_CALL\x10\xba\x17\x12\x1a\n\x15RTC_MISSED_VIDEO_CALL\x10\xbb\x17\x12\x19\n\x14RTC_GROUP_AUDIO_CALL\x10\xbc\x17\x12\x19\n\x14RTC_GROUP_VIDEO_CALL\x10\xbd\x17\x12 \n\x1bRTC_MISSED_GROUP_AUDIO_CALL\x10\xbe\x17\x12 \n\x1bRTC_MISSED_GROUP_VIDEO_CALL\x10\xbf\x17\x12\x1b\n\x16RTC_ONGOING_AUDIO_CALL\x10\xc0\x17\x12\x1b\n\x16RTC_ONGOING_VIDEO_CALL\x10\xc1\x17\x12 \n\x1bMSG_RECEIVER_FETCH_FALLBACK\x10\xd1\x17\x12\x1a\n\x15\x44\x41TACLASS_SENDER_COPY\x10\xa0\x1f\x42*Z(go.mau.fi/whatsmeow/proto/waArmadilloXMA')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloXMA.WAArmadilloXMA_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z(go.mau.fi/whatsmeow/proto/waArmadilloXMA'
  _globals['_EXTENDEDCONTENTMESSAGE']._serialized_start=81
  _globals['_EXTENDEDCONTENTMESSAGE']._serialized_end=3336
  _globals['_EXTENDEDCONTENTMESSAGE_CTA']._serialized_start=1033
  _globals['_EXTENDEDCONTENTMESSAGE_CTA']._serialized_end=1209
  _globals['_EXTENDEDCONTENTMESSAGE_OVERLAYICONGLYPH']._serialized_start=1212
  _globals['_EXTENDEDCONTENTMESSAGE_OVERLAYICONGLYPH']._serialized_end=1373
  _globals['_EXTENDEDCONTENTMESSAGE_CTABUTTONTYPE']._serialized_start=1375
  _globals['_EXTENDEDCONTENTMESSAGE_CTABUTTONTYPE']._serialized_end=1407
  _globals['_EXTENDEDCONTENTMESSAGE_XMALAYOUTTYPE']._serialized_start=1409
  _globals['_EXTENDEDCONTENTMESSAGE_XMALAYOUTTYPE']._serialized_end=1507
  _globals['_EXTENDEDCONTENTMESSAGE_EXTENDEDCONTENTTYPE']._serialized_start=1510
  _globals['_EXTENDEDCONTENTMESSAGE_EXTENDEDCONTENTTYPE']._serialized_end=3336
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waFingerprint/WAFingerprint.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waFingerprint/WAFingerprint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!waFingerprint/WAFingerprint.proto\x12\rWAFingerprint\"\xb7\x01\n\x0f\x46ingerprintData\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12\x14\n\x0cpnIdentifier\x18\x02 \x01(\x0c\x12\x15\n\rlidIdentifier\x18\x03 \x01(\x0c\x12\x1a\n\x12usernameIdentifier\x18\x04 \x01(\x0c\x12/\n\x0bhostedState\x18\x05 \x01(\x0e\x32\x1a.WAFingerprint.HostedState\x12\x17\n\x0fhashedPublicKey\x18\x06 \x01(\x0c\"\x9b\x01\n\x13\x43ombinedFingerprint\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x38\n\x10localFingerprint\x18\x02 \x01(\x0b\x32\x1e.WAFingerprint.FingerprintData\x12\x39\n\x11remoteFingerprint\x18\x03 \x01(\x0b\x32\x1e.WAFingerprint.FingerprintData*#\n\x0bHostedState\x12\x08\n\x04\x45\x32\x45\x45\x10\x00\x12\n\n\x06HOSTED\x10\x01\x42)Z\'go.mau.fi/whatsmeow/proto/waFingerprint')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waFingerprint.WAFingerprint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'go.mau.fi/whatsmeow/proto/waFingerprint'
  _globals['_HOSTEDSTATE']._serialized_start=396
  _globals['_HOSTEDSTATE']._serialized_end=431
  _globals['_FINGERPRINTDATA']._serialized_start=53
  _globals['_FINGERPRINTDATA']._serialized_end=236
  _globals['_COMBINEDFINGERPRINT']._serialized_start=239
  _globals['_COMBINEDFINGERPRINT']._serialized_end=394
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waChatLockSettings/WAProtobufsChatLockSettings.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waChatLockSettings/WAProtobufsChatLockSettings.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waUserPassword import WAProtobufsUserPassword_pb2 as waUserPassword_dot_WAProtobufsUserPassword__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4waChatLockSettings/WAProtobufsChatLockSettings.proto\x12\x1bWAProtobufsChatLockSettings\x1a,waUserPassword/WAProtobufsUserPassword.proto\"f\n\x10\x43hatLockSettings\x12\x17\n\x0fhideLockedChats\x18\x01 \x01(\x08\x12\x39\n\nsecretCode\x18\x02 \x01(\x0b\x32%.WAProtobufsUserPassword.UserPasswordB.Z,go.mau.fi/whatsmeow/proto/waChatLockSettings')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waChatLockSettings.WAProtobufsChatLockSettings_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,go.mau.fi/whatsmeow/proto/waChatLockSettings'
  _globals['_CHATLOCKSETTINGS']._serialized_start=131
  _globals['_CHATLOCKSETTINGS']._serialized_end=233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waQuickPromotionSurfaces/WAWebProtobufsQuickPromotionSurfaces.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waQuickPromotionSurfaces/WAWebProtobufsQuickPromotionSurfaces.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCwaQuickPromotionSurfaces/WAWebProtobufsQuickPromotionSurfaces.proto\x12$WAWebProtobufsQuickPromotionSurfaces\"\xe4\x05\n\x02QP\x1a\xe1\x01\n\x0c\x46ilterClause\x12G\n\nclauseType\x18\x01 \x02(\x0e\x32\x33.WAWebProtobufsQuickPromotionSurfaces.QP.ClauseType\x12\x46\n\x07\x63lauses\x18\x02 \x03(\x0b\x32\x35.WAWebProtobufsQuickPromotionSurfaces.QP.FilterClause\x12@\n\x07\x66ilters\x18\x03 \x03(\x0b\x32/.WAWebProtobufsQuickPromotionSurfaces.QP.Filter\x1a\xa3\x02\n\x06\x46ilter\x12\x12\n\nfilterName\x18\x01 \x02(\t\x12M\n\nparameters\x18\x02 \x03(\x0b\x32\x39.WAWebProtobufsQuickPromotionSurfaces.QP.FilterParameters\x12K\n\x0c\x66ilterResult\x18\x03 \x01(\x0e\x32\x35.WAWebProtobufsQuickPromotionSurfaces.QP.FilterResult\x12i\n\x18\x63lientNotSupportedConfig\x18\x04 \x02(\x0e\x32G.WAWebProtobufsQuickPromotionSurfaces.QP.FilterClientNotSupportedConfig\x1a.\n\x10\x46ilterParameters\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"0\n\x0c\x46ilterResult\x12\x08\n\x04TRUE\x10\x01\x12\t\n\x05\x46\x41LSE\x10\x02\x12\x0b\n\x07UNKNOWN\x10\x03\"J\n\x1e\x46ilterClientNotSupportedConfig\x12\x13\n\x0fPASS_BY_DEFAULT\x10\x01\x12\x13\n\x0f\x46\x41IL_BY_DEFAULT\x10\x02\"&\n\nClauseType\x12\x07\n\x03\x41ND\x10\x01\x12\x06\n\x02OR\x10\x02\x12\x07\n\x03NOR\x10\x03\x42\x34Z2go.mau.fi/whatsmeow/proto/waQuickPromotionSurfaces')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waQuickPromotionSurfaces.WAWebProtobufsQuickPromotionSurfaces_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2go.mau.fi/whatsmeow/proto/waQuickPromotionSurfaces'
  _globals['_QP']._serialized_start=110
  _globals['_QP']._serialized_end=850
  _globals['_QP_FILTERCLAUSE']._serialized_start=117
  _globals['_QP_FILTERCLAUSE']._serialized_end=342
  _globals['_QP_FILTER']._serialized_start=345
  _globals['_QP_FILTER']._serialized_end=636
  _globals['_QP_FILTERPARAMETERS']._serialized_start=638
  _globals['_QP_FILTERPARAMETERS']._serialized_end=684
  _globals['_QP_FILTERRESULT']._serialized_start=686
  _globals['_QP_FILTERRESULT']._serialized_end=734
  _globals['_QP_FILTERCLIENTNOTSUPPORTEDCONFIG']._serialized_start=736
  _globals['_QP_FILTERCLIENTNOTSUPPORTEDCONFIG']._serialized_end=810
  _globals['_QP_CLAUSETYPE']._serialized_start=812
  _globals['_QP_CLAUSETYPE']._serialized_end=850
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class QP(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _FilterResult:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FilterResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QP._FilterResult.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TRUE: QP._FilterResult.ValueType  # 1
        FALSE: QP._FilterResult.ValueType  # 2
        UNKNOWN: QP._FilterResult.ValueType  # 3

    class FilterResult(_FilterResult, metaclass=_FilterResultEnumTypeWrapper): ...
    TRUE: QP.FilterResult.ValueType  # 1
    FALSE: QP.FilterResult.ValueType  # 2
    UNKNOWN: QP.FilterResult.ValueType  # 3

    class _FilterClientNotSupportedConfig:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FilterClientNotSupportedConfigEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QP._FilterClientNotSupportedConfig.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PASS_BY_DEFAULT: QP._FilterClientNotSupportedConfig.ValueType  # 1
        FAIL_BY_DEFAULT: QP._FilterClientNotSupportedConfig.ValueType  # 2

    class FilterClientNotSupportedConfig(_FilterClientNotSupportedConfig, metaclass=_FilterClientNotSupportedConfigEnumTypeWrapper): ...
    PASS_BY_DEFAULT: QP.FilterClientNotSupportedConfig.ValueType  # 1
    FAIL_BY_DEFAULT: QP.FilterClientNotSupportedConfig.ValueType  # 2

    class _ClauseType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ClauseTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QP._ClauseType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        AND: QP._ClauseType.ValueType  # 1
        OR: QP._ClauseType.ValueType  # 2
        NOR: QP._ClauseType.ValueType  # 3

    class ClauseType(_ClauseType, metaclass=_ClauseTypeEnumTypeWrapper): ...
    AND: QP.ClauseType.ValueType  # 1
    OR: QP.ClauseType.ValueType  # 2
    NOR: QP.ClauseType.ValueType  # 3

    @typing.final
    class FilterClause(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CLAUSETYPE_FIELD_NUMBER: builtins.int
        CLAUSES_FIELD_NUMBER: builtins.int
        FILTERS_FIELD_NUMBER: builtins.int
        clauseType: global___QP.ClauseType.ValueType
        @property
        def clauses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QP.FilterClause]: ...
        @property
        def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QP.Filter]: ...
        def __init__(
            self,
            *,
            clauseType: global___QP.ClauseType.ValueType | None = ...,
            clauses: collections.abc.Iterable[global___QP.FilterClause] | None = ...,
            filters: collections.abc.Iterable[global___QP.Filter] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["clauseType", b"clauseType"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["clauseType", b"clauseType", "clauses", b"clauses", "filters", b"filters"]) -> None: ...

    @typing.final
    class Filter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FILTERNAME_FIELD_NUMBER: builtins.int
        PARAMETERS_FIELD_NUMBER: builtins.int
        FILTERRESULT_FIELD_NUMBER: builtins.int
        CLIENTNOTSUPPORTEDCONFIG_FIELD_NUMBER: builtins.int
        filterName: builtins.str
        filterResult: global___QP.FilterResult.ValueType
        clientNotSupportedConfig: global___QP.FilterClientNotSupportedConfig.ValueType
        @property
        def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QP.FilterParameters]: ...
        def __init__(
            self,
            *,
            filterName: builtins.str | None = ...,
            parameters: collections.abc.Iterable[global___QP.FilterParameters] | None = ...,
            filterResult: global___QP.FilterResult.ValueType | None = ...,
            clientNotSupportedConfig: global___QP.FilterClientNotSupportedConfig.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["clientNotSupportedConfig", b"clientNotSupportedConfig", "filterName", b"filterName", "filterResult", b"filterResult"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["clientNotSupportedConfig", b"clientNotSupportedConfig", "filterName", b"filterName", "filterResult", b"filterResult", "parameters", b"parameters"]) -> None: ...

    @typing.final
    class FilterParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str | None = ...,
            value: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    def __init__(
        self,
    ) -> None: ...

global___QP = QP



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waCompanionReg/WAWebProtobufsCompanionReg.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/waCompanionReg/WAWebProtobufsCompanionReg.proto\x12\x1aWAWebProtobufsCompanionReg\"\xd8\t\n\x0b\x44\x65viceProps\x12\n\n\x02os\x18\x01 \x01(\t\x12\x43\n\x07version\x18\x02 \x01(\x0b\x32\x32.WAWebProtobufsCompanionReg.DeviceProps.AppVersion\x12J\n\x0cplatformType\x18\x03 \x01(\x0e\x32\x34.WAWebProtobufsCompanionReg.DeviceProps.PlatformType\x12\x17\n\x0frequireFullSync\x18\x04 \x01(\x08\x12T\n\x11historySyncConfig\x18\x05 \x01(\x0b\x32\x39.WAWebProtobufsCompanionReg.DeviceProps.HistorySyncConfig\x1a\xf1\x03\n\x11HistorySyncConfig\x12\x19\n\x11\x66ullSyncDaysLimit\x18\x01 \x01(\r\x12\x1b\n\x13\x66ullSyncSizeMbLimit\x18\x02 \x01(\r\x12\x16\n\x0estorageQuotaMb\x18\x03 \x01(\r\x12%\n\x1dinlineInitialPayloadInE2EeMsg\x18\x04 \x01(\x08\x12\x1b\n\x13recentSyncDaysLimit\x18\x05 \x01(\r\x12\x1d\n\x15supportCallLogHistory\x18\x06 \x01(\x08\x12&\n\x1esupportBotUserAgentChatHistory\x18\x07 \x01(\x08\x12#\n\x1bsupportCagReactionsAndPolls\x18\x08 \x01(\x08\x12\x1b\n\x13supportBizHostedMsg\x18\t \x01(\x08\x12\x30\n(supportRecentSyncChunkMessageCountTuning\x18\n \x01(\x08\x12\x1d\n\x15supportHostedGroupMsg\x18\x0b \x01(\x08\x12!\n\x19supportFbidBotChatHistory\x18\x0c \x01(\x08\x12(\n supportAddOnHistorySyncMigration\x18\r \x01(\x08\x12!\n\x19supportMessageAssociation\x18\x0e \x01(\x08\x1ag\n\nAppVersion\x12\x0f\n\x07primary\x18\x01 \x01(\r\x12\x11\n\tsecondary\x18\x02 \x01(\r\x12\x10\n\x08tertiary\x18\x03 \x01(\r\x12\x12\n\nquaternary\x18\x04 \x01(\r\x12\x0f\n\x07quinary\x18\x05 \x01(\r\"\xdf\x02\n\x0cPlatformType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x43HROME\x10\x01\x12\x0b\n\x07\x46IREFOX\x10\x02\x12\x06\n\x02IE\x10\x03\x12\t\n\x05OPERA\x10\x04\x12\n\n\x06SAFARI\x10\x05\x12\x08\n\x04\x45\x44GE\x10\x06\x12\x0b\n\x07\x44\x45SKTOP\x10\x07\x12\x08\n\x04IPAD\x10\x08\x12\x12\n\x0e\x41NDROID_TABLET\x10\t\x12\t\n\x05OHANA\x10\n\x12\t\n\x05\x41LOHA\x10\x0b\x12\x0c\n\x08\x43\x41TALINA\x10\x0c\x12\n\n\x06TCL_TV\x10\r\x12\r\n\tIOS_PHONE\x10\x0e\x12\x10\n\x0cIOS_CATALYST\x10\x0f\x12\x11\n\rANDROID_PHONE\x10\x10\x12\x15\n\x11\x41NDROID_AMBIGUOUS\x10\x11\x12\x0b\n\x07WEAR_OS\x10\x12\x12\x0c\n\x08\x41R_WRIST\x10\x13\x12\r\n\tAR_DEVICE\x10\x14\x12\x07\n\x03UWP\x10\x15\x12\x06\n\x02VR\x10\x16\x12\r\n\tCLOUD_API\x10\x17\x12\x10\n\x0cSMARTGLASSES\x10\x18\"\x86\x01\n\x1a\x43ompanionEphemeralIdentity\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12H\n\ndeviceType\x18\x02 \x01(\x0e\x32\x34.WAWebProtobufsCompanionReg.DeviceProps.PlatformType\x12\x0b\n\x03ref\x18\x03 \x01(\t\"#\n\x13\x43ompanionCommitment\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\"z\n\x0fProloguePayload\x12\"\n\x1a\x63ompanionEphemeralIdentity\x18\x01 \x01(\x0c\x12\x43\n\ncommitment\x18\x02 \x01(\x0b\x32/.WAWebProtobufsCompanionReg.CompanionCommitment\"<\n\x18PrimaryEphemeralIdentity\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\x12\r\n\x05nonce\x18\x02 \x01(\x0c\"]\n\x0ePairingRequest\x12\x1a\n\x12\x63ompanionPublicKey\x18\x01 \x01(\x0c\x12\x1c\n\x14\x63ompanionIdentityKey\x18\x02 \x01(\x0c\x12\x11\n\tadvSecret\x18\x03 \x01(\x0c\"?\n\x17\x45ncryptedPairingRequest\x12\x18\n\x10\x65ncryptedPayload\x18\x01 \x01(\x0c\x12\n\n\x02IV\x18\x02 \x01(\x0c\"P\n\x12\x43lientPairingProps\x12\x1b\n\x13isChatDbLidMigrated\x18\x01 \x01(\x08\x12\x1d\n\x15isSyncdPureLidSession\x18\x02 \x01(\x08\x42*Z(go.mau.fi/whatsmeow/proto/waCompanionReg')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waCompanionReg.WAWebProtobufsCompanionReg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z(go.mau.fi/whatsmeow/proto/waCompanionReg'
  _globals['_DEVICEPROPS']._serialized_start=80
  _globals['_DEVICEPROPS']._serialized_end=1320
  _globals['_DEVICEPROPS_HISTORYSYNCCONFIG']._serialized_start=364
  _globals['_DEVICEPROPS_HISTORYSYNCCONFIG']._serialized_end=861
  _globals['_DEVICEPROPS_APPVERSION']._serialized_start=863
  _globals['_DEVICEPROPS_APPVERSION']._serialized_end=966
  _globals['_DEVICEPROPS_PLATFORMTYPE']._serialized_start=969
  _globals['_DEVICEPROPS_PLATFORMTYPE']._serialized_end=1320
  _globals['_COMPANIONEPHEMERALIDENTITY']._serialized_start=1323
  _globals['_COMPANIONEPHEMERALIDENTITY']._serialized_end=1457
  _globals['_COMPANIONCOMMITMENT']._serialized_start=1459
  _globals['_COMPANIONCOMMITMENT']._serialized_end=1494
  _globals['_PROLOGUEPAYLOAD']._serialized_start=1496
  _globals['_PROLOGUEPAYLOAD']._serialized_end=1618
  _globals['_PRIMARYEPHEMERALIDENTITY']._serialized_start=1620
  _globals['_PRIMARYEPHEMERALIDENTITY']._serialized_end=1680
  _globals['_PAIRINGREQUEST']._serialized_start=1682
  _globals['_PAIRINGREQUEST']._serialized_end=1775
  _globals['_ENCRYPTEDPAIRINGREQUEST']._serialized_start=1777
  _globals['_ENCRYPTEDPAIRINGREQUEST']._serialized_end=1840
  _globals['_CLIENTPAIRINGPROPS']._serialized_start=1842
  _globals['_CLIENTPAIRINGPROPS']._serialized_end=1922
# @@protoc_insertion_point(module_scope)



import asyncio
from enum import Enum
import json
import os
import shlex
import time
import subprocess
import tempfile
import logging
from typing import List, Optional, Tuple
from dataclasses import dataclass
from .iofile import (
    URL_MATCH,
    TemporaryFile,
    get_bytes_from_name_or_url,
    get_bytes_from_name_or_url_async,
)

log = logging.getLogger(__name__)


class ImageFormat(Enum):
    """
    Enumeration for image formats.

    Attributes:
        JPG (str): JPEG format identifier.
        PNG (str): PNG format identifier.
    """

    JPG = "mjpeg"
    PNG = "apng"


@dataclass
class Stream:
    """
    Data class representing a stream in multimedia.

    Attributes:
        index (int): Index of the stream.
        codec_type (str): Type of codec used in the stream.
        avg_frame_rate (str): Average frame rate of the stream.
        codec_tag_string (str): Codec tag string.
        start_pts (int): Starting presentation timestamp.
        tags (dict): Tags associated with the stream.
        extradata_size (int): Size of the extra data.
        start_time (str): Start time of the stream.
        disposition (dict): Disposition of the stream.
        codec_tag (str): Codec tag.
        time_base (str): Time base.
        codec_long_name (str): Long name of the codec.
        codec_name (str): Name of the codec.
        r_frame_rate (str): Real frame rate.
        closed_captions (Optional[int]): Closed captions (Video field).
        color_range (Optional[str]): Color range.
        display_aspect_ratio (Optional[str]): Display aspect ratio.
        color_transfer (Optional[str]): Color transfer.
        is_avc (Optional[str]): AVC flag.
        color_primaries (Optional[str]): Color primaries.
        film_grain (Optional[int]): Film grain.
        color_space (Optional[str]): Color space.
        refs (Optional[int]): Number of reference frames.
        level (Optional[int]): Codec level.
        nal_length_size (Optional[str]): NAL length size.
        chroma_location (Optional[str]): Chroma location.
        has_b_frames (Optional[int]): B-frames flag.
        pix_fmt (Optional[str]): Pixel format.
        sample_aspect_ratio (Optional[str]): Sample aspect ratio.
        bits_per_raw_sample (Optional[str]): Bits per raw sample.
        profile (Optional[str]): Codec profile.
        field_order (Optional[str]): Field order.
        width (Optional[int]): Width of the video frame.
        height (Optional[int]): Height of the video frame.
        coded_width (Optional[int]): Coded width of the video frame.
        coded_height (Optional[int]): Coded height of the video frame.
        bits_per_sample (Optional[int]): Bits per sample (Audio field).
        sample_fmt (Optional[str]): Sample format.
        channel_layout (Optional[str]): Channel layout.
        initial_padding (Optional[int]): Initial padding.
        channels (Optional[int]): Number of channels.
        sample_rate (Optional[str]): Sample rate.
    """

    index: int
    codec_type: str
    avg_frame_rate: str
    codec_tag_string: str
    start_pts: int
    tags: dict
    extradata_size: int
    start_time: str
    disposition: dict
    codec_tag: str
    time_base: str
    codec_long_name: str
    codec_name: str
    r_frame_rate: str
    closed_captions: Optional[int] = None
    color_range: Optional[str] = None
    display_aspect_ratio: Optional[str] = None
    color_transfer: Optional[str] = None
    is_avc: Optional[str] = None
    color_primaries: Optional[str] = None
    film_grain: Optional[int] = None
    color_space: Optional[str] = None
    refs: Optional[int] = None
    level: Optional[int] = None
    nal_length_size: Optional[str] = None
    chroma_location: Optional[str] = None
    has_b_frames: Optional[int] = None
    pix_fmt: Optional[str] = None
    sample_aspect_ratio: Optional[str] = None
    bits_per_raw_sample: Optional[str] = None
    profile: Optional[str] = None
    field_order: Optional[str] = None
    width: Optional[int] = None
    height: Optional[int] = None
    coded_width: Optional[int] = None
    coded_height: Optional[int] = None
    bits_per_sample: Optional[int] = None
    sample_fmt: Optional[str] = None
    channel_layout: Optional[str] = None
    initial_padding: Optional[int] = None
    channels: Optional[int] = None
    sample_rate: Optional[str] = None


@dataclass
class Format:
    """
    Data class representing the format of multimedia content.

    Attributes:
        filename (str): Name of the file.
        nb_streams (int): Number of streams in the file.
        nb_programs (int): Number of programs in the file.
        format_name (str): Name of the format.
        format_long_name (str): Long name of the format.
        start_time (float): Start time of the format.
        duration (float): Duration of the content.
        size (int): Size of the file in bytes.
        probe_score (int): Probe score of the file.
        tags (dict): Tags associated with the format.
    """

    filename: str
    nb_streams: int
    nb_programs: int
    format_name: str
    format_long_name: str
    start_time: float
    duration: float
    size: int
    probe_score: int
    tags: dict

    def __post_init__(self):
        for k, field in self.__class__.__dataclass_fields__.items():
            try:
                setattr(self, k, field.type(getattr(self, k)))
            except Exception as e:
                log.warn(f"{k} field: {e}")


@dataclass
class FFProbeInfo:
    """
    Data class representing FFProbe information for a media file.

    Attributes:
        format (Format): The format information of the media file.
        streams (List[Stream]): List of streams in the media file.
    """

    format: Format
    streams: List[Stream]


class AFFmpeg:
    def __init__(self, data: bytes | str, prefix: Optional[str] = None) -> None:
        """
        Initializes the FFmpeg class. If the data is a URL, it retrieves the data from the URL
        and writes it to a temporary file. If the data is a string that is not a URL, it treats
        the string as a filename. If the data is bytes, it writes the bytes to a temporary file.

        :param data: The input data. This can be a URL, a filename, or bytes.
        :type data: bytes | str
        :param prefix: The prefix for the temporary file, if one is created. If None, no prefix is used.
        :type prefix: Optional[str], optional
        """
        self.__file_data = data
        self.prefix = prefix

    async def __aenter__(self):
        if isinstance(self.__file_data, str):
            if URL_MATCH.match(self.__file_data):
                self.filename = TemporaryFile(prefix=self.prefix, touch=False).__enter__()
                with open(self.filename.path, "wb") as file:
                    file.write(await get_bytes_from_name_or_url_async(self.__file_data))
            else:
                self.filename = self.__file_data
        else:
            self.filename = TemporaryFile(prefix=self.prefix, touch=False).__enter__()
            with open(self.filename.path, "wb") as file:
                file.write(self.__file_data)
        return self

    async def __aexit__(self, *args, **kwargs):
        if not isinstance(self.filename, str):
            self.filename.__exit__(None, None, None)

    @property
    def filepath(self):
        if isinstance(self.filename, str):
            return self.filename
        return self.filename.path.__str__()

    async def cv_to_webp(self, animated: bool = True, enforce_not_broken: bool = False) -> bytes:
        """
        This function converts a given file to webp format using ffmpeg.
        If the animated flag is set to True, it will only convert the first 6 seconds of the file.

        :param animated: If True, only the first 6 seconds of the file will be converted, defaults to True
        :type animated: bool, optional
        :param enforce_not_broken: Enforce non-broken stickers by constraining sticker size to WA limits, defaults to False
        :type enforce_not_broken: bool, optional
        :return: The converted file in bytes
        :rtype: bytes
        """
        MAX_STICKER_FILESIZE = 512000
        temp = tempfile.gettempdir() + "/" + time.time().__str__() + ".webp"
        ffmpeg_command = [
            "ffmpeg",
            "-i",
            self.filepath,
            "-vcodec",
            "libwebp",
            "-vf",
            (
                "scale='if(gt(iw,ih),512,-1)':'if(gt(iw,ih),-1,512)',fps=15, "
                "pad=512:512:-1:-1:color=white@0.0, split [a][b]; [a] "
                "palettegen=reserve_transparent=on:transparency_color=ffffff [p]; [b][p] paletteuse"
            ),
        ]
        if enforce_not_broken:
            duration = int((await self.extract_info()).format.duration)
            if not duration:
                duration = 1
            if duration > 6 and animated:
                duration = 6
            bitrate = f"{MAX_STICKER_FILESIZE // duration}k"
            ffmpeg_command.extend(
                [
                    "-loop",
                    "0",
                    "-preset",
                    "picture",
                    "-fs",
                    f"{MAX_STICKER_FILESIZE}",
                    "-q:v",
                    bitrate,
                ]
            )
        if animated:
            ffmpeg_command.extend(
                [
                    "-ss",
                    "00:00:00.0",
                    "-t",
                    "00:00:06.0",
                ]
            )
        ffmpeg_command.append(temp)
        await self.call(ffmpeg_command)
        with open(temp, "rb") as file:
            buf = file.read()
        os.remove(temp)
        return buf

    async def call(self, cmd: List[str]):
        cmd_str = shlex.join(cmd) if any(" " in part for part in cmd) else " ".join(cmd)
        popen = await asyncio.create_subprocess_shell(
            cmd_str if os.name == "nt" else shlex.join(cmd),
            stderr=asyncio.subprocess.PIPE,
            stdout=asyncio.subprocess.PIPE,
            stdin=subprocess.DEVNULL,
            # shell=True if os.name == "nt" else False,
        )
        stdout, stderr = await popen.communicate()  # type: ignore
        if popen.returncode != 0:
            raise RuntimeError(
                f"stderr: {stderr} Return code: {popen.returncode}"  # type: ignore
            )
        return stdout

    async def gif_to_mp4(self) -> bytes:
        """
        This function convertes a gif to mp4 format.
        """
        temp = tempfile.gettempdir() + "/" + time.time().__str__() + ".mp4"
        await self.call(
            [
                "ffmpeg",
                "-i",
                self.filepath,
                "-movflags",
                "faststart",
                "-pix_fmt",
                "yuv420p",
                "-vf",
                "scale=trunc(iw/2)*2:trunc(ih/2)*2",
                "-crf",
                "17",
                temp,
            ]
        )
        with open(temp, "rb") as file:
            buf = file.read()
        os.remove(temp)
        return buf

    async def to_mp3(self) -> bytes:
        temp = tempfile.gettempdir() + "/" + time.time().__str__() + ".mp3"
        await self.call(
            [
                "ffmpeg",
                "-i",
                self.filepath,
                "-vn",
                "-ar",
                "44100",
                "-ac",
                "2",
                "-b:a",
                "192k",
                temp,
            ]
        )
        with open(temp, "rb") as file:
            buf = file.read()
        os.remove(temp)
        return buf

    async def extract_thumbnail(
        self,
        format: ImageFormat = ImageFormat.JPG,
        size: Optional[Tuple[int, int] | int] = 200,
    ) -> bytes:
        """
        Extracts a thumbnail from a video file.

        :param format: The format of the output thumbnail, defaults to ImageFormat.JPG
        :type format: ImageFormat, optional
        :param size: The size of the output thumbnail. If an integer is provided, the thumbnail will be scaled
                     while maintaining the aspect ratio. If a tuple of two integers is provided, it will be used
                     as the exact dimensions for the thumbnail, defaults to 200
        :type size: Optional[Tuple[int, int]  |  int], optional
        :return: The bytes representing the thumbnail image.
        :rtype: bytes
        """
        extra = []
        if isinstance(size, int):
            for stream in (await self.extract_info()).streams:
                if stream.codec_type == "video":
                    extra.extend(
                        [
                            "-vf",
                            "scale='if(gt(iw,ih),%i,-1)':'if(gt(iw,ih),-1,%i)'" % (size, size),
                        ]
                    )
        elif isinstance(size, Tuple):
            extra.extend(["-s", "x".join(map(str, size))])
        return await self.call(
            [
                "ffmpeg",
                "-i",
                self.filepath,
                "-vframes",
                "1",
                "-an",
                *extra,
                "-f",
                format.value,
                "-",
            ]
        )

    async def extract_info(self) -> FFProbeInfo:
        """
        Extracts media file information using ffprobe tool.

        This method uses ffprobe, a tool from the FFmpeg package, to extract
        information about a media file. It returns the information in the form of
        an FFProbeInfo object, which contains the format and streams of the media file.

        :return: An FFProbeInfo object containing the format and streams of the media file.
        :rtype: FFProbeInfo
        """
        data = json.loads(
            await self.call(
                [
                    "ffprobe",
                    "-i",
                    self.filepath,
                    "-print_format",
                    "json",
                    "-show_format",
                    "-show_streams",
                ]
            )
        )
        streams: List[dict] = data["streams"]
        format: dict = data["format"]
        return FFProbeInfo(
            format=Format(
                **{i: format.get(i, None) for i, _ in Format.__dataclass_fields__.items()}
            ),
            streams=[
                Stream(
                    **{
                        field: data.get(field, None)
                        for field, _ in Stream.__dataclass_fields__.items()
                    }
                )
                for data in streams
            ],
        )


class FFmpeg:
    def __init__(self, data: bytes | str, prefix: Optional[str] = None) -> None:
        """
        Initializes the FFmpeg class. If the data is a URL, it retrieves the data from the URL
        and writes it to a temporary file. If the data is a string that is not a URL, it treats
        the string as a filename. If the data is bytes, it writes the bytes to a temporary file.

        :param data: The input data. This can be a URL, a filename, or bytes.
        :type data: bytes | str
        :param prefix: The prefix for the temporary file, if one is created. If None, no prefix is used.
        :type prefix: Optional[str], optional
        """
        if isinstance(data, str):
            if URL_MATCH.match(data):
                self.filename = TemporaryFile(prefix=prefix, touch=False).__enter__()
                with open(self.filename.path, "wb") as file:
                    file.write(get_bytes_from_name_or_url(data))
            else:
                self.filename = data
        else:
            self.filename = TemporaryFile(prefix=prefix, touch=False).__enter__()
            with open(self.filename.path, "wb") as file:
                file.write(data)

    def __enter__(self):
        return self

    def __exit__(self, *ex):
        if not isinstance(self.filename, str):
            self.filename.__exit__(None, None, None)

    @property
    def filepath(self):
        if isinstance(self.filename, str):
            return self.filename
        return self.filename.path.__str__()

    def cv_to_webp(self, animated: bool = True, enforce_not_broken: bool = False) -> bytes:
        """
        This function converts a given file to webp format using ffmpeg.
        If the animated flag is set to True, it will only convert the first 6 seconds of the file.

        :param animated: If True, only the first 6 seconds of the file will be converted, defaults to True
        :type animated: bool, optional
        :param enforce_not_broken: Enforce non-broken stickers by constraining sticker size to WA limits, defaults to False
        :type enforce_not_broken: bool, optional
        :return: The converted file in bytes
        :rtype: bytes
        """
        MAX_STICKER_FILESIZE = 512000
        temp = tempfile.gettempdir() + "/" + time.time().__str__() + ".webp"
        ffmpeg_command = [
            "ffmpeg",
            "-i",
            self.filepath,
            "-vcodec",
            "libwebp",
            "-vf",
            (
                "scale='if(gt(iw,ih),512,-1)':'if(gt(iw,ih),-1,512)',fps=15, "
                "pad=512:512:-1:-1:color=white@0.0, split [a][b]; [a] "
                "palettegen=reserve_transparent=on:transparency_color=ffffff [p]; [b][p] paletteuse"
            ),
        ]
        if enforce_not_broken:
            duration = int(self.extract_info().format.duration)
            if not duration:
                duration = 1
            if duration > 6 and animated:
                duration = 6
            bitrate = f"{MAX_STICKER_FILESIZE // duration}k"
            ffmpeg_command.extend(
                [
                    "-loop",
                    "0",
                    "-preset",
                    "picture",
                    "-fs",
                    f"{MAX_STICKER_FILESIZE}",
                    "-q:v",
                    bitrate,
                ]
            )
        if animated:
            ffmpeg_command.extend(
                [
                    "-ss",
                    "00:00:00.0",
                    "-t",
                    "00:00:06.0",
                ]
            )
        ffmpeg_command.append(temp)
        self.call(ffmpeg_command)
        with open(temp, "rb") as file:
            buf = file.read()
        os.remove(temp)
        return buf

    def call(self, cmd: List[str]):
        popen = subprocess.Popen(
            cmd,
            stderr=subprocess.PIPE,
            stdout=subprocess.PIPE,
            stdin=subprocess.DEVNULL,
        )
        out = popen.stdout.read()  # type: ignore
        popen.wait(10)
        if popen.returncode != 0:
            raise RuntimeError(
                f"stderr: {popen.stderr.read().decode()} Return code: {popen.returncode}"  # type: ignore
            )
        return out

    def gif_to_mp4(self) -> bytes:
        """
        This function convertes a gif to mp4 format.
        """
        temp = tempfile.gettempdir() + "/" + time.time().__str__() + ".mp4"
        self.call(
            [
                "ffmpeg",
                "-i",
                self.filepath,
                "-movflags",
                "faststart",
                "-pix_fmt",
                "yuv420p",
                "-vf",
                "scale=trunc(iw/2)*2:trunc(ih/2)*2",
                "-crf",
                "17",
                temp,
            ]
        )
        with open(temp, "rb") as file:
            buf = file.read()
        os.remove(temp)
        return buf

    def to_mp3(self) -> bytes:
        temp = tempfile.gettempdir() + "/" + time.time().__str__() + ".mp3"
        self.call(
            [
                "ffmpeg",
                "-i",
                self.filepath,
                "-vn",
                "-ar",
                "44100",
                "-ac",
                "2",
                "-b:a",
                "192k",
                temp,
            ]
        )
        with open(temp, "rb") as file:
            buf = file.read()
        os.remove(temp)
        return buf

    def extract_thumbnail(
        self,
        format: ImageFormat = ImageFormat.JPG,
        size: Optional[Tuple[int, int] | int] = 200,
    ) -> bytes:
        """
        Extracts a thumbnail from a video file.

        :param format: The format of the output thumbnail, defaults to ImageFormat.JPG
        :type format: ImageFormat, optional
        :param size: The size of the output thumbnail. If an integer is provided, the thumbnail will be scaled
                     while maintaining the aspect ratio. If a tuple of two integers is provided, it will be used
                     as the exact dimensions for the thumbnail, defaults to 200
        :type size: Optional[Tuple[int, int]  |  int], optional
        :return: The bytes representing the thumbnail image.
        :rtype: bytes
        """
        extra = []
        if isinstance(size, int):
            for stream in self.extract_info().streams:
                if stream.codec_type == "video":
                    extra.extend(
                        [
                            "-vf",
                            "scale='if(gt(iw,ih),%i,-1)':'if(gt(iw,ih),-1,%i)'" % (size, size),
                        ]
                    )
        elif isinstance(size, Tuple):
            extra.extend(["-s", "x".join(map(str, size))])
        return self.call(
            [
                "ffmpeg",
                "-i",
                self.filepath,
                "-vframes",
                "1",
                "-an",
                *extra,
                "-f",
                format.value,
                "-",
            ]
        )

    def extract_info(self) -> FFProbeInfo:
        """
        Extracts media file information using ffprobe tool.

        This method uses ffprobe, a tool from the FFmpeg package, to extract
        information about a media file. It returns the information in the form of
        an FFProbeInfo object, which contains the format and streams of the media file.

        :return: An FFProbeInfo object containing the format and streams of the media file.
        :rtype: FFProbeInfo
        """
        data = json.loads(
            self.call(
                [
                    "ffprobe",
                    "-i",
                    self.filepath,
                    "-print_format",
                    "json",
                    "-show_format",
                    "-show_streams",
                ]
            )
        )
        streams: List[dict] = data["streams"]
        format: dict = data["format"]
        return FFProbeInfo(
            format=Format(
                **{i: format.get(i, None) for i, _ in Format.__dataclass_fields__.items()}
            ),
            streams=[
                Stream(
                    **{
                        field: data.get(field, None)
                        for field, _ in Stream.__dataclass_fields__.items()
                    }
                )
                for data in streams
            ],
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waEphemeral/WAWebProtobufsEphemeral.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waEphemeral/WAWebProtobufsEphemeral.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)waEphemeral/WAWebProtobufsEphemeral.proto\x12\x17WAWebProtobufsEphemeral\"7\n\x10\x45phemeralSetting\x12\x10\n\x08\x64uration\x18\x01 \x01(\x0f\x12\x11\n\ttimestamp\x18\x02 \x01(\x10\x42\'Z%go.mau.fi/whatsmeow/proto/waEphemeral')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waEphemeral.WAWebProtobufsEphemeral_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z%go.mau.fi/whatsmeow/proto/waEphemeral'
  _globals['_EPHEMERALSETTING']._serialized_start=70
  _globals['_EPHEMERALSETTING']._serialized_end=125
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class EphemeralSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    duration: builtins.int
    timestamp: builtins.int
    def __init__(
        self,
        *,
        duration: builtins.int | None = ...,
        timestamp: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["duration", b"duration", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["duration", b"duration", "timestamp", b"timestamp"]) -> None: ...

global___EphemeralSetting = EphemeralSetting
